#!/usr/bin/perl
# Copyright (C) 2007-2009 Timesys Corporation
use strict;
use warnings;
use File::Find::Rule;
use DBI;
use Data::Dumper;

my $dbh     = DBI->connect('dbi:Pg:dbname=factory', 'postgres', '', {AutoCommit => 0})
                or die "Failed to connect to db: $!";
my $unit_stm= $dbh->prepare("insert into unit (id, name, version, revision, label, description, disabled) values (?,?,?,?,?,?,?)");
my $attr_stm= $dbh->prepare("insert into unitattribute (name, value, unit_id) values (?,?,?)");
my @configs = File::Find::Rule->file()->name( 'Config.in' )->in( 'target/software' );
#my @configs = File::Find::Rule->file()->name( 'Config.in' )->in( 'toolchain' );
my @invalid = qw( target/software/Config.in target/software/Application/Config.in target/software/Development/Config.in target/software/Multimedia/Config.in target/software/Networking/Config.in target/software/System/Config.in toolchain/cc/Config.in toolchain/libc/Config.in toolchain/Config.in );

our $regex = {
    name                => qr/config TSWO_([^ ]+)_VERSION/s,
    version             => qr/config TSWO_[^ ]+_VERSION\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    url                 => qr/config TSWO_[^ ]+_URL\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    source              => qr/config TSWO_[^ ]+_SOURCE\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    patches             => qr/config TSWO_[^ ]+_PATCHES\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    files               => qr/config TSWO_[^ ]+_FILES\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    depends             => qr/config TSWO_[^ ]+_DEPENDS\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    runtime_depends     => qr/config TSWO_[^ ]+_RUNTIME_DEPENDS\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    working_dir         => qr/config TSWO_[^ ]+_WORKINGDIR\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    basic_make          => qr/config TSWO_[^ ]+_BASIC_MAKE\n\s+bool\n\s+default\s+([yn]*)\n/s,
    configure_options   => qr/config TSWO_[^ ]+_CONFIGURE_OPTIONS\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    build_options       => qr/config TSWO_[^ ]+_BUILD_OPTIONS\n\s+string.*?\n\s+default\s+[\"\']?([^\"]*)[\"\']?\n/s,
    description         => qr/menuconfig TSWO_SOFTWARE_[^ ]+\n\s+.*?help\n\s+([^\n]+)\n/s,
};


#$dbh->begin_work();

for my $config (@configs)
{
    next if grep {m/$config/} @invalid;
    open (my $fh, '<', $config) or die "Failed to open $config: $!";
    my $data; { local $/; $data = <$fh>;}
    my $cat = (split(/\//,$config))[2];

    my $pkg = parse_package_data(\$data, $cat);
    create_package_entry($pkg);

    close($fh);
}

$dbh->rollback();
#$dbh->commit();


sub parse_package_data
{
    my ($data, $category) = @_;

    my $obj = { category => $category, installed_size => undef, build_time => undef };

    if ($$data =~ m/$regex->{name}/s)                { $obj->{name} = $1; }
    if ($$data =~ m/$regex->{version}/s)             { $obj->{version} = $1; }
    if ($$data =~ m/$regex->{url}/s)                 { $obj->{url} = $1; }
    if ($$data =~ m/$regex->{source}/s)              { $obj->{source} = $1; }
    if ($$data =~ m/$regex->{patches}/s)             { $obj->{patches} = $1; }
    if ($$data =~ m/$regex->{files}/s)               { $obj->{files} = $1; }
    if ($$data =~ m/$regex->{depends}/s)             { $obj->{depends} = $1; }
    if ($$data =~ m/$regex->{runtime_depends}/s)     { $obj->{runtime_depends} = $1; }
    if ($$data =~ m/$regex->{working_dir}/s)         { $obj->{working_dir} = $1; }
    if ($$data =~ m/$regex->{basic_make}/s)          { $obj->{basic_make} = $1; }
    if ($$data =~ m/$regex->{configure_options}/s)   { $obj->{configure_options} = $1; }
    if ($$data =~ m/$regex->{build_options}/s)       { $obj->{build_options} = $1; }
    if ($$data =~ m/$regex->{description}/s)         { $obj->{description} = $1; }

    return $obj;
}

sub get_next_seq_val
{
    $dbh->selectrow_array("select nextval('unit_id_seq')");
}

sub create_package_entry
{
    my $pkg     = shift;
    my $new_id  = get_next_seq_val();

    my @pkg_opts = ($new_id);
    push @pkg_opts, map $pkg->{$_}, qw(name version);
    push @pkg_opts, "1";
    push @pkg_opts, map $pkg->{$_}, qw(name description);
    push @pkg_opts, undef;

    $unit_stm->execute(@pkg_opts);

    for my $attr (qw(source patches files depends runtime_depends working_dir basic_make configure_options build_options category installed_size build_time))
    {
        $attr_stm->execute($attr, $pkg->{$attr}, $new_id);
    }
}
