#!/bin/bash
# Pretty Print The TimeSys Work Order
#
# Copyright (C) 2007-2009 Timesys Corporation
# Justin Waters
# 2008 June 24
#
# This little script outputs the package information in the TSWO file in a
# format that can be copied and pasted into either twiki or Redmine.
#
# 2008 Sept 25 - JJW - Made tables prettier and added categories to packages
# 2008 June 24 - JJW - Initial version
#
FILE=$1

if ! [[ $FILE ]]; then
  echo "Usage: $0 [FILE]"
  echo ""
  echo "List all host and target packages in the TimeSys workorder FILE in a Wiki Tabular format"
  exit 1
fi

function find_version {
  if [[ $1 == "gdbserver" ]]; then
     PKGNAME=gdb
  else
     PKGNAME=$1
  fi
  VERSION=`grep "^TSWO_${PKGNAME}_VERSION" $FILE |  sed -e "s/TSWO_${PKGNAME}_VERSION=\"//" -e "s/\"//"`
}

function find_category {
  CATEGORY=`dirname target/software/*/$1 | xargs basename`
  if [[ $CATEGORY == '*' ]]; then
     CATEGORY="Host Tools"
  fi
}
function find_license {
  if [[ $1 == "gdbserver" ]]; then
     PKGNAME=gdb
  else
     PKGNAME=$1
  fi
  LICENSE=$(egrep '^# [^ ]+ license: ' target/software/*/$PKGNAME/Config.in 2>/dev/null | cut -f2 -d:)
  if [ -z "$LICENSE" ]; then
    LICENSE=$(egrep '^# [^ ]+ license: ' toolchain/$PKGNAME/Config.in 2>/dev/null | cut -f2 -d:)
  fi
  if [ -z "$LICENSE" ]; then
    LICENSE=$(egrep '^# [^ ]+ license: ' toolchain/*/$PKGNAME/Config.in 2>/dev/null | cut -f2 -d:)
  fi
}

echo "System"
echo "|----------------------------------------|"

BOARD=`grep "^TSWO_BOARD=" $FILE | sed -e "s/TSWO_BOARD=\"//" -e "s/\"//"`
printf "| %-20s " "Board Name"
printf "| %-15s " "$BOARD"
echo "|"

ARCH=`grep "^TSWO_ARCH=" $FILE | sed -e "s/TSWO_ARCH=\"//" -e "s/\"//"`
printf "| %-20s " "Architecture"
printf "| %-15s " "$ARCH"
echo "|"

KARCH=`grep "^TSWO_KERNEL_ARCH=" $FILE | sed -e "s/TSWO_KERNEL_ARCH=\"//" -e "s/\"//"`
printf "| %-20s " "Kernel Architecture"
printf "| %-15s " "$KARCH"
echo "|"

find_version kernel
printf "| %-20s " "Kernel Version"
printf "| %-15s " "$VERSION"
echo "|"

OUTPUTFORMAT=`grep TSWO_PACKAGE_AS_[[:alnum:]]*=y $FILE | sed -e "s/=y//" -e "s/TSWO_PACKAGE_AS_//"`
printf "| %-20s " "Package Output"
printf "| %-15s " "$OUTPUTFORMAT"
echo "|"

echo "|----------------------------------------|"

echo ""
echo "Toolchain"
echo "|-------------------------------------------------------|"
find_version binutils
printf "| %-12s " "Binutils"
printf "| %-20s " "binutils"
printf "| %-15s " "$VERSION"
echo "|"

CC=`grep "^TSWO_CC=" $FILE | sed -e "s/TSWO_CC=\"//" -e "s/\"//"`
find_version $CC
printf "| %-12s " "CC"
printf "| %-20s " "$CC"
printf "| %-15s " "$VERSION"
echo "|"

LIBC=`grep "^TSWO_LIBC=" $FILE | sed -e "s/"TSWO_LIBC="\"//" -e "s/\"//"`
find_version $LIBC
printf "| %-12s " "libc"
printf "| %-20s " "$LIBC"
printf "| %-15s " "$VERSION"
echo "|"

if [[ `grep "^TSWO_GDB=y" $FILE` ]]; then
  find_version gdb
  printf "| %-12s " "Debugger"
  printf "| %-20s " "gdb"
  printf "| %-15s " "$VERSION"
  echo "|"
fi
echo "|-------------------------------------------------------|"

HOSTTOOLS=`grep TSWO_HOSTTOOL_[[:alnum:][:punct:]]*=y $FILE | sed -e "s/=y//" -e "s/TSWO_HOSTTOOL_//"`

echo ""
echo "Host Tools"
echo "|----------------------------------------|"
printf "| %-20s " "Package"
printf "| %-15s " "Version"
echo "|"
echo "|----------------------|-----------------|"
for PACKAGE in $HOSTTOOLS; do

  # Hacks for mkimage and mtd-utils
  if [[ $PACKAGE == "mtdutils" ]]; then
    find_version mtd-utils
  elif [[ $PACKAGE == "mkimage" ]]; then
    find_version u-boot
  else
    find_version $PACKAGE
  fi
  printf "| %-20s " "$PACKAGE"
  printf "| %-15s " "$VERSION"
  echo "|"
done
echo "|----------------------------------------|"

echo ""
echo "RFS Optimization Options"
echo "|---------------------------------------------|"
printf "| %-35s " "Option"
printf "| %-5s " "Value"
echo "|"
echo "|-------------------------------------|-------|"


VALUE=`grep "^TSWO_RFS_STRIP=" $FILE | sed -e "s/TSWO_RFS_STRIP=//"`
printf "| %-35s " "Strip Libraries"
printf "| %-5s " $VALUE
echo "|"

VALUE=`grep "^TSWO_RFS_RM_MAN=" $FILE | sed -e "s/TSWO_RFS_RM_MAN=//"`
printf "| %-35s " "Remove Man Pages"
printf "| %-5s " $VALUE
echo "|"

VALUE=`grep "^TSWO_RFS_RM_INFO=" $FILE | sed -e "s/TSWO_RFS_RM_INFO=//"`
printf "| %-35s " "Remove Info Pages"
printf "| %-5s " $VALUE
echo "|"

VALUE=`grep "^TSWO_RFS_RM_INCLUDE=" $FILE | sed -e "s/TSWO_RFS_RM_INCLUDE=//"`
printf "| %-35s " "Remove Development Headers"
printf "| %-5s " $VALUE
echo "|"

VALUE=`grep "^TSWO_RFS_RM_STATIC_LIB=" $FILE | sed -e "s/TSWO_RFS_RM_STATIC_LIB=//"`
printf "| %-35s " "Remove static library files"
printf "| %-5s " $VALUE
echo "|"

VALUE=`grep "^TSWO_RFS_RM_IL8N_LOCALE_ZONEINFO=" $FILE | sed -e "s/TSWO_RFS_RM_IL8N_LOCALE_ZONEINFO=//"`
printf "| %-35s " "Remove il8n, locale, and zoneinfo"
printf "| %-5s " $VALUE
echo "|"

VALUE=`grep "^TSWO_RFS_RM_DOC=" $FILE | sed -e "s/TSWO_RFS_RM_DOC=//"`
printf "| %-35s " "Remove doc directories"
printf "| %-5s " $VALUE
echo "|"

echo "|---------------------------------------------|"

OUTPUT=`grep TSWO_RFS_FS_[[:alnum:]]*=y $FILE | sed -e "s/=y//" -e "s/TSWO_RFS_FS_//"`

echo ""
echo "RFS Output Formats"
echo "|--------------|"
for OP in $OUTPUT; do
  printf "| %-12s " $OP
  echo "|"
done
echo "|--------------|"

PACKAGES=`grep TSWO_SOFTWARE_[[:alnum:][:punct:]]*=y $FILE | sed -e "s/=y//" -e "s/TSWO_SOFTWARE_//"`

echo ""
echo "Packages"
echo "|---------------------------------------------------------------------------------|"
printf "| %-11s " "Category"
printf "| %-29s " "Package"
printf "| %-10s " "Version"
printf "| %-20s " "License"
echo "|"
echo "|-------------|-------------------------------|------------|----------------------|"
for PACKAGE in $PACKAGES; do
  find_category $PACKAGE
  find_version $PACKAGE
  find_license $PACKAGE
  printf "| %-11s " "${CATEGORY:0:11}"
  printf "| %-29s " "${PACKAGE:0:25}"
  printf "| %-10s " "${VERSION:0:10}"
  printf "| %-20s " "${LICENSE:0:20}"
  echo "|"
done
echo "|---------------------------------------------------------------------------------|"
