#!/bin/bash


CATEGORIES=$(find target/software/  -mindepth 1 -maxdepth 1 -type d -exec basename {} \;)
DIRBASE=target/software/
PS3="New category: "


recategorize()
{
  type=$1

  local PACKAGES
  case "$type" in
    package)
      if [ -z "$2" ]; then
        return
      fi
      PACKAGES=$(ls $DIRBASE/*/$2/Config.in)
    ;;
    category)
      if [ -z "$2" ]; then
        return
      fi
      PACKAGES=$(ls $DIRBASE/$2/*/Config.in)
    ;;
    *)
      PACKAGES=$(ls $DIRBASE/*/*/Config.in)
    ;;
  esac

  for p in $PACKAGES
  do
    clear
    pkg=$(echo $p |cut -f5 -d\/)
    current_cat=$(echo $p | cut -f4 -d\/)
    echo "-- $pkg in $current_cat"
    ./bin/describe_pkg.sh $pkg
    echo
    select cat in $CATEGORIES QUIT
    do
      case "$cat" in
        "QUIT")
          exit
        ;;
        *)
          if [ "$current_cat" != "$cat" ]; then
            if [ -d .git ]; then
              git mv $DIRBASE$current_cat/$pkg $DIRBASE$cat/$pkg
            fi
            sed -i -r -e ":a N;\$!ba; s,(.*)[\n\r]+endmenu,\1," $DIRBASE$cat/Config.in
            grep "\/$pkg\/Config.in" $DIRBASE$current_cat/Config.in | sed -re "s/$current_cat/$cat/" >> $DIRBASE$cat/Config.in
            echo 'endmenu' >> $DIRBASE$cat/Config.in
            sed -i "/\/$pkg\/Config.in/d" $DIRBASE$current_cat/Config.in
          fi
          break
        ;;
      esac
    done
  done
}

usage()
{
  echo "Usage: $0 [package|category|all] [name]"
  echo "       $0 package xorg-server"
  echo "       $0 category System"
  echo "       $0 all"
  exit 1
}

case "$1" in
  all)
    recategorize 
  ;;
  category)
    if [ -z "$2" ]; then
      usage
    fi
    recategorize category $2
  ;;
  package)
    if [ -z "$2" ]; then
      usage
    fi
    recategorize package $2
  ;;
  *)
    usage
  ;;
esac

