#!/bin/bash
# Copyright (C) 2007-2009 Timesys Corporation

trap true SIGINT

WO=.config
BACKUP_WO=.config_$$
WORKING_WO=.config_upgrade_workorder_$$

if [ ! -f $WO ]; then
  echo "No $WO to parse"
  exit 1
fi

OPT=$1
if [ -z "$OPT" ]; then
  echo "Usage: $0 [--show|--upgrade]"
  echo "--show                 - print difference of versions and patches from the defaults"
  echo "--upgrade [--noprompt] - modify work order (.config) file with new configuration"
  exit 1
fi
NOPROMPT=$2

# read in important values
BOARD=$(grep '^TSWO_BOARD_' $WO | sed -re 's/TSWO_BOARD_(.*)=y/\1/')
LIBC=$(grep '^TSWO_LIBC_' $WO | sed -re 's/TSWO_LIBC_(.*)=y/\1/' | grep -v PORTS)
HOSTTOOLS=$(grep '^TSWO_HOSTTOOL_' $WO | sed -re 's/TSWO_HOSTTOOL_(.*)=y/\1/g' | xargs)
APPLICATIONS=$(grep '^TSWO_SOFTWARE_' $WO | sed -re 's/TSWO_SOFTWARE_(.*)=y/\1/g' | xargs)
BOOTLOADERS=$(grep '^TSWO_BOOTLOADER_' $WO | sed -re 's/TSWO_BOOTLOADER_(.*)=y/\1/g' | xargs)
UPGRADESFOUND=

# make a backup copy and a working copy
cp -f $WO $BACKUP_WO
cp -f $WO $WORKING_WO


# generate a barebones .config
echo '' > $WO
echo "TSWO_BOARD_$BOARD=y" >> $WO
echo "TSWO_LIBC_$LIBC=y" >> $WO
for ht in $HOSTTOOLS
do
  echo "TSWO_HOSTTOOL_$ht=y" >> $WO
done
for app in $APPLICATIONS
do
  echo "TSWO_SOFTWARE_$app=y" >> $WO
done
if [ -f .config.old ]; then cp -f .config.old .config.old.$$;fi
yes '' | make oldconfig &>/dev/null
if [ -f .config.old.$$ ]; then mv -f .config.old.$$ .config.old; else rm -f .config.old;fi


function compare_unit
{
  local OLDVERSION=$(grep "^TSWO_$1_VERSION=" $BACKUP_WO | sed -re "s/^TSWO_$1_VERSION=\"(.*)\"$/\1/")
  local OLDSOURCE=$(grep "^TSWO_$1_SOURCE=" $BACKUP_WO | sed -re "s/^TSWO_$1_SOURCE=\"(.*)\"$/\1/")
  local OLDPATCHES=$(grep "^TSWO_$1_PATCHES=" $BACKUP_WO | sed -re "s/^TSWO_$1_PATCHES=\"(.*)\"$/\1/")
  local OLDFILES=$(grep "^TSWO_$1_FILES=" $BACKUP_WO | sed -re "s/^TSWO_$1_FILES=\"(.*)\"$/\1/")
  local OLDCONFIG=$(grep "^TSWO_$1_CONFIGURE_OPTIONS=" $BACKUP_WO | sed -re "s/^TSWO_$1_CONFIGURE_OPTIONS=\"(.*)\"$/\1/")
  local OLDBUILD=$(grep "^TSWO_$1_BUILD_OPTIONS=" $BACKUP_WO | sed -re "s/^TSWO_$1_BUILD_OPTIONS=\"(.*)\"$/\1/")
  local OLDDEP=$(grep "^TSWO_$1_DEPENDS=" $BACKUP_WO | sed -re "s/^TSWO_$1_DEPENDS=\"(.*)\"$/\1/")
  local OLDRDEP=$(grep "^TSWO_$1_RUNTIME_DEPENDS=" $BACKUP_WO | sed -re "s/^TSWO_$1_RUNTIME_DEPENDS=\"(.*)\"$/\1/")

  local NEWVERSION=$(grep "^TSWO_$1_VERSION=" $WO | sed -re "s/^TSWO_$1_VERSION=\"(.*)\"$/\1/")
  local NEWSOURCE=$(grep "^TSWO_$1_SOURCE=" $WO | sed -re "s/^TSWO_$1_SOURCE=\"(.*)\"$/\1/")
  local NEWPATCHES=$(grep "^TSWO_$1_PATCHES=" $WO | sed -re "s/^TSWO_$1_PATCHES=\"(.*)\"$/\1/")
  local NEWFILES=$(grep "^TSWO_$1_FILES=" $WO | sed -re "s/^TSWO_$1_FILES=\"(.*)\"$/\1/")
  local NEWCONFIG=$(grep "^TSWO_$1_CONFIGURE_OPTIONS=" $WO | sed -re "s/^TSWO_$1_CONFIGURE_OPTIONS=\"(.*)\"$/\1/")
  local NEWBUILD=$(grep "^TSWO_$1_BUILD_OPTIONS=" $WO | sed -re "s/^TSWO_$1_BUILD_OPTIONS=\"(.*)\"$/\1/")
  local NEWDEP=$(grep "^TSWO_$1_DEPENDS=" $WO | sed -re "s/^TSWO_$1_DEPENDS=\"(.*)\"$/\1/")
  local NEWRDEP=$(grep "^TSWO_$1_RUNTIME_DEPENDS=" $WO | sed -re "s/^TSWO_$1_RUNTIME_DEPENDS=\"(.*)\"$/\1/")

  local VERSIONDIFF=
  local SOURCEDIFF=
  local PATCHDIFF=
  local FILEDIFF=
  local CONFIGDIFF=
  local BUILDDIFF=
  local DEPDIFF=
  local RDEPDIFF=
  if [[ -n "$OLDVERSION" && -n "$NEWVERSION" && "$NEWVERSION" != "$OLDVERSION" ]]; then
    VERSIONDIFF=1
  fi
  if [[ -n "$OLDSOURCE" && -n "$NEWSOURCE" && "$NEWSOURCE" != "$OLDSOURCE" ]]; then
    SOURCEDIFF=1
  fi
  if [ "$NEWPATCHES" != "$OLDPATCHES" ]; then
    PATCHDIFF=1
  fi
  if [ "$NEWFILES" != "$OLDFILES" ]; then
    FILEDIFF=1
  fi
  if [ "$NEWCONFIG" != "$OLDCONFIG" ]; then
    CONFIGDIFF=1
  fi
  if [ "$NEWBUILD" != "$OLDBUILD" ]; then
    BUILDDIFF=1
  fi
  if [ "$NEWDEP" != "$OLDDEP" ]; then
    DEPDIFF=1
  fi
  if [ "$NEWRDEP" != "$OLDRDEP" ]; then
    RDEPDIFF=1
  fi

  if [ -n "$VERSIONDIFF" -o -n "$SOURCEDIFF" -o -n "$PATCHDIFF" -o -n "$FILEDIFF" -o -n "$CONFIGDIFF" -o -n "$BUILDDIFF" -o -n "$DEPDIFF" -o -n "$RDEPDIFF" ]; then
    UPGRADESFOUND=1
    echo "Differing default values for: $1"
    if [ "$OPT" = "--upgrade" ]; then
      case "$1" in
        gcc|gdb|glibc|uClibc|binutils|kernel)
        ;;
        *)
          REQUIRED_BY=$(./bin/whatrequires.sh $1 | xargs)
          if [ -n "$REQUIRED_BY" ]; then
            echo "Required by: $REQUIRED_BY"
          fi
          echo "Description:"
          ./bin/describe_pkg.sh $1 | sed -re 's/^/ /g'
        ;;
        esac
        printf "Differing default values:\n"
    fi

    if [ -n "$VERSIONDIFF" ]; then
      echo -e " Version: $OLDVERSION -> $NEWVERSION"
    fi
    if [ -n "$SOURCEDIFF" ]; then
      echo -e " Source: $OLDSOURCE -> $NEWSOURCE"
    fi
    if [ -n "$PATCHDIFF" ]; then
      echo -e " Patches: " $NEWPATCHES
    fi
    if [ -n "$FILEDIFF" ]; then
      echo -e " Files: " $NEWFILES
    fi
    if [ -n "$CONFIGDIFF" ]; then
      echo -e " Configure Options: " $NEWCONFIG
    fi
    if [ -n "$BUILDDIFF" ]; then
      echo -e " Build Options: " $NEWBUILD
    fi
    if [ -n "$DEPDIFF" ]; then
      echo -e " Dependencies: " $NEWDEP
    fi
    if [ -n "$RDEPDIFF" ]; then
      echo -e " Runtime Dependencies: " $NEWRDEP
    fi

    if [ "$OPT" = "--upgrade" ]; then
      if [ -z "$NOPROMPT" ]; then
        printf "Apply this configuration? [Ny] "
        read apply
      else
        apply=y
      fi
      case "$apply" in
        Y*|y*)
          case "$1" in
            gcc|gdb|glibc|uClibc|binutils|kernel)
              local UPPER_NAME=$(echo ${1} | tr '[:lower:]' '[:upper:]')
              sed -i -re "/TSWO_${UPPER_NAME}_/d" $WORKING_WO
            ;;
          esac
          sed -i -re "/^TSWO_$1_VERSION=/d" $WORKING_WO
          sed -i -re "/^TSWO_$1_SOURCE=/d" $WORKING_WO
          sed -i -re "/^TSWO_$1_PATCHES=/d" $WORKING_WO
          sed -i -re "/^TSWO_$1_FILES=/d" $WORKING_WO
          sed -i -re "/^TSWO_$1_DEPENDS=/d" $WORKING_WO
          sed -i -re "/^TSWO_$1_RUNTIME_DEPENDS=/d" $WORKING_WO
          sed -i -re "/^TSWO_$1_CONFIGURE_OPTIONS=/d" $WORKING_WO
          sed -i -re "/^TSWO_$1_BUILD_OPTIONS=/d" $WORKING_WO
        ;;
      esac
    fi
    printf "\n"

  fi

}

function compare_option
{
  local OLDVALUE=$(grep "^$1=" $BACKUP_WO | sed -re "s/^$1=\"(.*)\"$/\1/")
  local NEWVALUE=$(grep "^$1=" $WO | sed -re "s/^$1=\"(.*)\"$/\1/")

  if [[ -n "$OLDVALUE" && -n "$NEWVALUE" && "$NEWVALUE" != "$OLDVALUE" ]]; then
    UPGRADESFOUND=1
    printf "Differing default values for %s:\n'%s' -> '%s'\n" $1 "$OLDVALUE" "$NEWVALUE"
    if [ "$OPT" = "--upgrade" ]; then
      if [ -z "$NOPROMPT" ]; then
        printf "Apply this configuration? [Ny] "
        read apply
      else
        apply=y
      fi # if prompt
      case "$apply" in
        Y*|y*)
          sed -i -re "/^$1=/d" $WORKING_WO
        ;;
      esac
    fi # if upgrade
    printf "\n"
  fi # if found
}

# check for differences between the kconfig defaults and our .config values
grep ^TSWO_KERNEL_INTERNAL=y .config &>/dev/null && \
  compare_unit kernel

for ht in gcc gdb glibc uClibc binutils $HOSTTOOLS $APPLICATIONS $BOOTLOADERS
do
  compare_unit $ht
done

for opt in TSWO_TARGET_CFLAGS TSWO_TARGET_CXXFLAGS TSWO_TARGET_LDFLAGS TSWO_TARGET_BUILD_OPTIONS TSWO_TARGET_CONFIGURE_OPTIONS TSWO_DEVICE_TABLE TSWO_HOST_BUILD_OPTIONS
do
  compare_option $opt
done

# report if requested
if [ "$OPT" = "--show" ]; then
  if [ -z "$UPGRADESFOUND" ]; then
    echo "-- No upgrades found"
  else
    S=$(echo $0 | sed -re "s|$PWD|\.|")
    echo "To merge these configuration changes run: make update"
  fi
fi

# if we are setting new defaults
if [ "$OPT" = "--upgrade" ]; then
  # nothing changed... revert to our backup
  if [ -z "$UPGRADESFOUND" ]; then
    mv -f $BACKUP_WO $WO
  # we have something different, run oldconfig on our working copy
  else 
    mv -f $WORKING_WO $WO
    yes '' | make oldconfig &>/dev/null
    mv -f $BACKUP_WO ${WO}.old
  fi
fi

# cleanup
if [ -f $BACKUP_WO ]; then
  mv -f $BACKUP_WO $WO
fi
if [ -f $WORKING_WO ]; then
  rm -f $WORKING_WO
fi
