# Copyright (C) 2007-2009 Timesys Corporation


.PHONY: host host_setup toolchain fetch_toolchain host-util-toolchain-dep

host: host_setup source toolchain

ifeq (y,$(strip $(TSWO_HOSTTOOL_ccache)))
TOOLCHAIN_CCACHE_DEP_TARGET=ccache-host-install
endif
ifeq (y,$(strip $(TSWO_TOOLCHAIN_cygwin)))
TOOLCHAIN_CYGWIN_DEP_TARGET=cygwin
endif

ifeq (y,$(TSWO_TC_FETCH))
toolchain: fetch_toolchain archive_pristine_toolchain_libs host-utilities toolchain_xml
host-util-toolchain-dep: fetch_toolchain
else
toolchain: host_setup $(TOOLCHAIN_CCACHE_DEP_TARGET) stage3_cc host-utilities toolchain_xml toolchain-initial-package $(TOOLCHAIN_CYGWIN_DEP_TARGET)
host-util-toolchain-dep: stage3_cc
endif

initial_toolchain=$(BUILD_DIR)/toolchain-initial-$(TSWO_FULL_TARGET_NAME).tgz
final_toolchain=$(BUILD_DIR)/toolchain-final-$(TSWO_FULL_TARGET_NAME).tgz

$(initial_toolchain):
	$(call PRINT_INFO,packaging toolchain (initial))
	$(call CREATE_TGZ, $(TSWO_HOST_INSTALL_DIR),$(initial_toolchain))

$(final_toolchain):
	$(call PRINT_INFO,packaging toolchain (final))
	$(call CREATE_TGZ, $(TSWO_HOST_INSTALL_DIR),$(final_toolchain))

toolchain-initial-package: host_setup stage3_cc host-utilities toolchain_xml $(initial_toolchain)
toolchain-final-package: toolchain $(final_toolchain)

host_setup:
	@mkdir -p $(TSWO_HOST_INSTALL_DIR)/bin
ifeq (y,$(strip $(TSWO_64BIT)))
	@mkdir -p $(TSWO_HOST_INSTALL_DIR)/lib
	@mkdir -p $(TSWO_HOST_INSTALL_DIR)/$(TSWO_FULL_TARGET_NAME)/lib
	@cd $(TSWO_HOST_INSTALL_DIR) && ln -sf lib lib64
	@cd $(TSWO_HOST_INSTALL_DIR)/$(TSWO_FULL_TARGET_NAME) && ln -sf lib lib64
endif
	@install -m 755 /dev/null $(TSWO_HOST_INSTALL_DIR)/bin/ldconfig

TC_FETCH_LOCATION=$(call UNQUOTE_VAR,$(TSWO_TC_FETCH_LOCATION))
TC_FILENAME=$(notdir $(TC_FETCH_LOCATION))
fetch_toolchain: host_setup
	$(call PRINT_INFO,Fetching pre-built toolchain)
ifeq ("",$(strip $(TSWO_TC_FETCH_LOCATION)))
	$(call PRINT_ERROR,Please specify a toolchain location in your workorder!)
endif
	$(call FETCH_REMOTE,$(BUILD_DIR),$(TSWO_TC_FETCH_LOCATION))
	@$(INFLATE$(suffix $(TC_FILENAME))) $(BUILD_DIR)/$(TC_FILENAME) | \
		$(TAR) -C $(TSWO_HOST_INSTALL_DIR) $(TSWO_TAR_OPTIONS) -
	@# make the cross strip available in the path first
	@cd $(TSWO_HOST_INSTALL_DIR)/bin && if [ ! -f strip ]; then ln -sf *-strip strip;fi
	$(call SETUP_CCACHE)

# make an archive of the pristine libraries from the binary toolchain
BINARY_TOOLCHAIN_COPY_DIR=$(BUILD_DIR)/binary_toolchain_pristine
archive_pristine_toolchain_libs: fetch_toolchain $(BINARY_TOOLCHAIN_COPY_DIR)/libc/libc.so $(BINARY_TOOLCHAIN_COPY_DIR)/libgcc/libgcc_s.so

$(BINARY_TOOLCHAIN_COPY_DIR)/libc/libc.so:
	mkdir -p $(BINARY_TOOLCHAIN_COPY_DIR)/libc
	if [ -z "$$($(TARGET_CROSS_PREFIX)gcc --print-file-name=libc.so)" ]; then echo "unable to locate binary C library"; exit 1; fi
	cd $(dir $(shell $(TARGET_CROSS_PREFIX)gcc --print-file-name=libc.so)) && \
		$(TAR) -cf - * --exclude 'libgcc*' --exclude 'libstdc++*'| tar -C $(BINARY_TOOLCHAIN_COPY_DIR)/libc -xf -
	cp -rf $(shell $(TARGET_CROSS_PREFIX)gcc --print-file-name=libc.so) $(BINARY_TOOLCHAIN_COPY_DIR)/libc/
$(BINARY_TOOLCHAIN_COPY_DIR)/libgcc/libgcc_s.so:
	mkdir -p $(BINARY_TOOLCHAIN_COPY_DIR)/libgcc
	if [ -z "$$($(TARGET_CROSS_PREFIX)gcc --print-file-name=libgcc_s.so))" ]; then echo "unable to locate binary libgcc"; exit 1; fi
	cd $(dir $(shell $(TARGET_CROSS_PREFIX)gcc --print-file-name=libgcc_s.so)) && \
		$(TAR) -cf - * | tar -C $(BINARY_TOOLCHAIN_COPY_DIR)/libgcc -xf -

ifndef HOSTAR
HOSTAR:=ar
endif
ifndef HOSTAS
HOSTAS:=as
endif
ifndef HOSTCC
HOSTCC:=gcc
else
endif
ifndef HOSTCXX
HOSTCXX:=g++
endif
ifndef HOSTFC
HOSTFC:=gfortran
endif
ifndef HOSTCPP
HOSTCPP:=cpp
endif
ifndef HOSTLD
HOSTLD:=ld
endif
ifndef HOSTLN
HOSTLN:=ln
endif
ifndef HOSTNM
HOSTNM:=nm
endif
HOSTAR:=$(shell which $(HOSTAR) 2>/dev/null || type -p $(HOSTAR) || echo ar)
HOSTAS:=$(shell which $(HOSTAS) 2>/dev/null || type -p $(HOSTAS) || echo as)
HOSTCC:=$(shell which $(HOSTCC) 2>/dev/null || type -p $(HOSTCC) || echo gcc)
HOSTCXX:=$(shell which $(HOSTCXX) 2>/dev/null || type -p $(HOSTCXX) || echo g++)
HOSTCPP:=$(shell which $(HOSTCPP) 2>/dev/null || type -p $(HOSTCPP) || echo cpp)
HOSTLD:=$(shell which $(HOSTLD) 2>/dev/null || type -p $(HOSTLD) || echo ld)
HOSTLN:=$(shell which $(HOSTLN) 2>/dev/null || type -p $(HOSTLN) || echo ln)
HOSTNM:=$(shell which $(HOSTNM) 2>/dev/null || type -p $(HOSTNM) || echo nm)
BZCAT:=$(shell which bzcat 2>/dev/null || which bzcat2 2>/dev/null)
ZCAT:=$(shell which zcat 2>/dev/null)
XZCAT:=$(shell which xzcat 2>/dev/null)
TAR:=$(shell which tar 2>/dev/null || which gtar 2>/dev/null || which gnutar 2>/dev/null)
SED:=$(shell which sed 2>/dev/null || echo /bin/sed)
INSTALL:=$(shell which install 2>/dev/null || echo /bin/install)
FIND:=$(shell which find 2>/dev/null || echo /usr/bin/find)
PERL:=$(shell which perl 2>/dev/null || echo /usr/bin/perl)
export HOSTAR HOSTAS HOSTCC HOSTCXX HOSTFC HOSTLD

# vim:set noexpandtab: 
