# Copyright (C) 2007-2009 Timesys Corporation

.PHONY: target rfs target_setup custom_rfs_content

target: host rfs toolchain-final-package

# perform libc-rfs-install after rfs-software as the presence of uClibc for some packages
# while installing throws off the linker.
ifneq (,$(strip $(call UNQUOTE_VAR,$(TSWO_BUILD_RFS))))
rfs: target_setup rfs-software libc-rfs-install kernel-rfs-install rfs-images
else
rfs:
endif

target_setup:
	@mkdir -p $(TSWO_RFS_INSTALL_DIR)/{etc/{network/{if-down.d,if-post-down.d,if-pre-up.d,if-up.d,run},init.d},lib,usr/{include,lib,bin,sbin},bin,sbin,proc,tmp,sys,mnt,opt,var/{log,tmp,run,lock}}
ifeq (y,$(strip $(TSWO_64BIT)))
	@cd $(TSWO_RFS_INSTALL_DIR)/ && ln -sf lib lib64
	@cd $(TSWO_RFS_INSTALL_DIR)/usr && ln -sf lib lib64
endif
	@if [ ! -e $(TSWO_RFS_INSTALL_DIR)/etc/group ]; then \
		echo "root:x:0:" > $(TSWO_RFS_INSTALL_DIR)/etc/group; \
	fi
	@if [ ! -e $(TSWO_RFS_INSTALL_DIR)/etc/passwd ]; then \
		echo "root::0:0::/root:/bin/sh" > $(TSWO_RFS_INSTALL_DIR)/etc/passwd; \
	fi
	@if [ ! -e $(TSWO_RFS_INSTALL_DIR)/etc/issue ]; then \
		echo "Distribution built using LinuxLink by Timesys" > $(TSWO_RFS_INSTALL_DIR)/etc/issue; \
		echo "Kernel \r for \m" >> $(TSWO_RFS_INSTALL_DIR)/etc/issue; \
	fi
	@if [ ! -e $(TSWO_RFS_INSTALL_DIR)/etc/fstab ]; then \
		echo "proc /proc proc defaults 0 0" \
			> $(TSWO_RFS_INSTALL_DIR)/etc/fstab; \
		echo "sysfs /sys sysfs defaults 0 0" \
			>> $(TSWO_RFS_INSTALL_DIR)/etc/fstab; \
		echo "tmpfs /tmp tmpfs defaults 0 0" \
			>> $(TSWO_RFS_INSTALL_DIR)/etc/fstab; \
		echo "none /dev/pts devpts defaults 0 0" \
			>> $(TSWO_RFS_INSTALL_DIR)/etc/fstab; \
		echo "tmpfs /dev/shm tmpfs defaults,mode=0777 0 0" \
			>> $(TSWO_RFS_INSTALL_DIR)/etc/fstab; \
	fi
	@if [ ! -e $(TSWO_RFS_INSTALL_DIR)/etc/hosts ]; then \
		echo "127.0.0.1 localhost.localdomain localhost" \
			> $(TSWO_RFS_INSTALL_DIR)/etc/hosts; \
		echo "127.0.0.1 $(TSWO_BOARD)" \
			>> $(TSWO_RFS_INSTALL_DIR)/etc/hosts; \
	fi
	@touch $(TSWO_RFS_INSTALL_DIR)/etc/resolv.conf
	@if [ ! -e $(TSWO_RFS_INSTALL_DIR)/etc/mtab ]; then \
		cd $(TSWO_RFS_INSTALL_DIR)/etc && ln -sf ../proc/mounts mtab; \
	fi
	@touch $(TSWO_RFS_INSTALL_DIR)/etc/network/interfaces
	@touch $(TSWO_RFS_INSTALL_DIR)/var/log/messages
	@if [ ! -e $(TSWO_RFS_INSTALL_DIR)/etc/hostname ]; then \
		echo $(TSWO_BOARD) > $(TSWO_RFS_INSTALL_DIR)/etc/hostname; \
	fi
	@if [ ! -e $(TSWO_RFS_INSTALL_DIR)/etc/timezone ]; then \
		echo 'US/Eastern' > $(TSWO_RFS_INSTALL_DIR)/etc/timezone; \
	fi
	@if [ ! -e $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf ]; then \
		echo "passwd: compat"       > $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
		echo "group: compat"        >> $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
		echo "shadow: compat"       >> $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
		echo "hosts: files dns"     >> $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
		echo "networks files"       >> $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
		echo "protocols: db files"  >> $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
		echo "services: db files"   >> $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
		echo "ethers: db files"     >> $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
		echo "rpc: db files"        >> $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
		echo "netgroup: nis"        >> $(TSWO_RFS_INSTALL_DIR)/etc/nsswitch.conf; \
	fi

device_table=$(strip $(call UNQUOTE_VAR,$(TSWO_DEVICE_TABLE)))
$(SRC_DL_DIR)/device_table:
	$(call PRINT_INFO,fetching device table)
	@rm -f $@
	$(call FETCH_REMOTE,$(SRC_DL_DIR),$(device_table))
	-@mv -f $(SRC_DL_DIR)/$(notdir $(device_table)) $@
	@touch -c $@

$(BUILD_DIR)/.rfs.sh: target_setup rfs-software libc-rfs-install $(SRC_DL_DIR)/device_table makedevs-host-install
	$(call PRINT_INFO,generating RFS script)
	@rm -rf $@
	@echo "export PATH=$(BUILD_PATH)" >> $@
ifeq (y,$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_STRIP))))
	@echo "echo 'Stripping binaries and libraries...'" >> $@
	@echo "find $(TSWO_RFS_INSTALL_DIR)/{lib,usr/lib,bin,sbin,usr/bin,usr/sbin} -type f -perm /+x -exec $(TARGET_CROSS_PREFIX)strip {} \; 2>/dev/null" >> $@
endif
ifeq (y,$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_RM_MAN))))
	@echo "echo 'Removing man pages...'" >> $@
	@echo "rm -rf $(TSWO_RFS_INSTALL_DIR)/usr/{man,share/man} 2>/dev/null" >> $@
endif
ifeq (y,$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_RM_INFO))))
	@echo "echo 'Removing info pages...'" >> $@
	@echo "rm -rf $(TSWO_RFS_INSTALL_DIR)/usr/{info,share/info} 2>/dev/null" >> $@
endif
ifeq (y,$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_RM_IL8N_LOCALE_ZONEINFO))))
	@echo "echo 'Removing i18n, locale, zoneinfo, and gconv files...'" >> $@
	@echo "rm -rf $(TSWO_RFS_INSTALL_DIR)/usr/{share,lib}/{i18n,locale,zoneinfo,gconv} 2>/dev/null" >> $@
endif
ifeq (y,$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_RM_INCLUDE))))
	@echo "echo 'Removing development headers...'" >> $@
	@echo "rm -rf $(TSWO_RFS_INSTALL_DIR)/usr/include 2>/dev/null" >> $@
endif
ifeq (y,$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_RM_DOC))))
	@echo "echo 'Removing documentation...'" >> $@
	@echo "rm -rf $(TSWO_RFS_INSTALL_DIR)/usr/{doc,docs,share/doc,share/docs,share/gtk-doc} 2>/dev/null" >> $@
endif
ifeq (y,$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_RM_STATIC_LIB))))
	@echo "echo 'Removing static library files...'" >> $@
	@echo "find $(TSWO_RFS_INSTALL_DIR)/{lib,usr/lib} -name '*.a' -exec rm -f {} \; 2>/dev/null" >> $@
endif
ifeq (y,$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_RM_INITSCRIPTS))))
	@echo "echo 'Removing init scripts...'" >> $@
	@echo "find $(TSWO_RFS_INSTALL_DIR)/etc/init.d/ ! -type d ! -name 'rc' -a ! -name 'rc[KS]' -a ! -name 'rc.local' -exec rm {} \;" >> $@
endif
ifneq (,$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_CUSTOM_INITSCRIPT))))
	$(call FETCH_REMOTE,$(SRC_DL_DIR),$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_CUSTOM_INITSCRIPT))))
	@echo "echo 'Installing custom init script...'" >> $@
	@echo "mkdir -p $(TSWO_RFS_INSTALL_DIR)/etc/init.d 2>/dev/null" >> $@
	@echo "if [ -e $(TSWO_RFS_INSTALL_DIR)/etc/init.d/rc.local ]; then rm $(TSWO_RFS_INSTALL_DIR)/etc/init.d/rc.local;fi 2>/dev/null" >> $@
	@echo "cp -f $(SRC_DL_DIR)/$(notdir $(strip $(call UNQUOTE_VAR,$(TSWO_RFS_CUSTOM_INITSCRIPT)))) $(TSWO_RFS_INSTALL_DIR)/etc/init.d/rc.local 2>/dev/null" >> $@
	@echo "chmod +x $(TSWO_RFS_INSTALL_DIR)/etc/init.d/rc.local 2>/dev/null" >> $@
endif
	@echo "echo 'Creating devices...'" >> $@
	@echo "$(TSWO_HOST_INSTALL_DIR)/bin/makedevs -d $(SRC_DL_DIR)/device_table $(TSWO_RFS_INSTALL_DIR) 2>/dev/null" >> $@
	@touch -c $@

custom_rfs_content:
	$(call PRINT_INFO,installing custom RFS content)
	$(call FETCH_REMOTE,$(SRC_DL_DIR),$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_CONTENT))))
	$(INFLATE$(suffix $(strip $(call UNQUOTE_VAR,$(TSWO_RFS_CONTENT))))) $(SRC_DL_DIR)/$(notdir $(strip $(call UNQUOTE_VAR,$(TSWO_RFS_CONTENT)))) | \
		$(TAR) -C $(TSWO_RFS_INSTALL_DIR) $(TSWO_TAR_OPTIONS) -

# vim:set noexpandtab: 
