# Copyright (C) 2007-2009 Timesys Corporation
# u-boot make rules

# Define common macros for this u-boot from include/common.mk
$(eval $(call COMMON_SETUP,u-boot))


$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_configured:
	$(call PRINT_INFO,configuring u-boot $(TSWO_UBOOT_CONFIGTARGET))
ifneq ("",$(strip $(TSWO_UBOOT_CONFIGFILE)))
	$(call FETCH_REMOTE,$(u-boot_SRC_DL_DIR),$(TSWO_UBOOT_CONFIGFILE))
	cp -f $(u-boot_SRC_DL_DIR)/$(notdir $(call UNQUOTE_VAR,$(TSWO_UBOOT_CONFIGFILE))) $(u-boot_DDIR)/include/configs/
endif
	cd $(u-boot_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(MAKE) \
		$(u-boot_BUILD_OPTIONS) \
		$(TSWO_UBOOT_CONFIGTARGET)_config
	@touch $@

$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_built:
	$(call PRINT_INFO,building u-boot)
	cd $(u-boot_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(MAKE) \
		$(u-boot_BUILD_OPTIONS) \
		HOSTSTRIP=/usr/bin/strip \
		CROSS_COMPILE=$(TSWO_FULL_TARGET_NAME)-
	cd $(u-boot_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(MAKE) \
		$(u-boot_BUILD_OPTIONS) \
		HOSTSTRIP=/usr/bin/strip \
		CROSS_COMPILE=$(TSWO_FULL_TARGET_NAME)- \
		tools
	-cd $(u-boot_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(MAKE) \
		$(u-boot_BUILD_OPTIONS) \
		HOSTSTRIP=/usr/bin/strip \
		CROSS_COMPILE=$(TSWO_FULL_TARGET_NAME)- \
		env
	@touch $@

MKIMAGE_HOST_DIR=$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/u-boot-host-build
MKIMAGE_HOST_BUILD_DIR=$(MKIMAGE_HOST_DIR)/u-boot-$(u-boot_VERSION)
$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_mkimage_host_installed:
	$(call PRINT_INFO,building mkimage for the host)
	mkdir -p $(MKIMAGE_HOST_DIR)
	$(INFLATE$(suffix $(u-boot_SOURCE))) $(u-boot_SRC_DL_DIR)/$(u-boot_SOURCE) | \
		$(TAR) -C $(MKIMAGE_HOST_DIR) $(TSWO_TAR_OPTIONS) -
	$(foreach patch,$(u-boot_PATCHES),$(call APPLY_PATCH,$(MKIMAGE_HOST_BUILD_DIR)/,$(u-boot_SRC_DL_DIR)/$(patch)))
ifneq ("",$(strip $(TSWO_UBOOT_CONFIGFILE)))
	$(call FETCH_REMOTE,$(u-boot_SRC_DL_DIR),$(TSWO_UBOOT_CONFIGFILE))
	cp -f $(u-boot_SRC_DL_DIR)/$(notdir $(call UNQUOTE_VAR,$(TSWO_UBOOT_CONFIGFILE))) $(MKIMAGE_HOST_BUILD_DIR)/include/configs/
endif
	cd $(MKIMAGE_HOST_BUILD_DIR) && \
		PATH=$(BUILD_PATH) \
		$(MAKE) \
		$(u-boot_BUILD_OPTIONS) \
		$(TSWO_UBOOT_CONFIGTARGET)_config
	cd $(MKIMAGE_HOST_BUILD_DIR) && \
		$(MAKE) \
		$(u-boot_BUILD_OPTIONS) \
		CROSS_COMPILE= \
		PLATFORM_CPPFLAGS= \
		PLATFORM_RELFLAGS= \
		tools
	cp -f $(MKIMAGE_HOST_BUILD_DIR)/tools/mkimage $(TSWO_HOST_INSTALL_DIR)/bin/
	-cp -f $(MKIMAGE_HOST_BUILD_DIR)/tools/img2srec $(TSWO_HOST_INSTALL_DIR)/bin/
	@touch $@

mkimage-fetch: u-boot-fetch
mkimage-unpack: u-boot-unpack
mkimage-patch: u-boot-patch
mkimage-configure:
mkimage-build:
mkimage-rfs-install:
mkimage-package:
mkimage-clean:
mkimage-distclean:
mkimage-host-install: mkimage-patch $(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_configured $(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_mkimage_host_installed

$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_images_installed:
	@mkdir -p $(IMAGES_DIR)/bootloader/
	cp -f $(u-boot_DDIR)/u-boot{*.bin,,.map,.srec} $(IMAGES_DIR)/bootloader/
	@touch $@

$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_host_installed: mkimage-host-install $(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_images_installed
	@touch $@
$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_rfs_installed: $(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_images_installed
ifeq (y,$(strip $(TSWO_INSTALL_TOOLCHAIN_TO_TARGET)))
	mkdir -p $(TSWO_RFS_INSTALL_DIR)/bin/
	-cp -f $(u-boot_DDIR)/tools/{mkimage,img2srec} $(TSWO_RFS_INSTALL_DIR)/bin/
	-cp -f $(u-boot_DDIR)/tools/env/fw_printenv $(TSWO_RFS_INSTALL_DIR)/bin/ && \
		cd $(TSWO_RFS_INSTALL_DIR)/bin/ && \
		ln -s fw_printenv fw_setenv
endif
	@touch $@
$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_packaged: $(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_images_installed
	cp -f $(u-boot_DDIR)/u-boot{*.bin,,.map,.srec} $(u-boot_PKG_INSTALL_DIR)
	mkdir -p $ $(u-boot_PKG_INSTALL_DIR)/bin
	-cp -f $(u-boot_DDIR)/tools/{mkimage,img2srec} $(u-boot_PKG_INSTALL_DIR)/bin/
	-cp -f $(u-boot_DDIR)/tools/env/fw_printenv $(u-boot_PKG_INSTALL_DIR)/bin/ && \
		cd $(u-boot_PKG_INSTALL_DIR)/bin/ && \
		ln -s fw_printenv fw_setenv
	@touch $@
$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/.stamp_checked:
	@touch $@


# Combined u-boot, kernel, and optionally RFS
$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/ubootblob.lds:
	$(call PRINT_INFO,building u-boot blob linker script)
	echo "OUTPUT_FORMAT(\"elf32-littlearm\", \"elf32-littlearm\", \"elf32-littlearm\")" > $@
	echo "OUTPUT_ARCH(arm)" >> $@
	echo "ENTRY(_start)" >> $@
	echo "SECTIONS" >> $@
	echo "{" >> $@
	echo "  _start = 0x80e80000;" >> $@
	echo "  .text 0x80e80000 : { *(.text) }" >> $@
	echo "  .uImage $(strip $(call UNQUOTE_VAR,$(TSWO_UBOOT_COMBINE_WITH_KERNEL_ADDRESS))) : { *(.uImage) }" >> $@
	echo "  .rootfs $(strip $(call UNQUOTE_VAR,$(TSWO_UBOOT_COMBINE_WITH_KERNEL_AND_RFS_ADDRESS))) : { *(.rootfs) }" >> $@
	echo "}" >> $@

$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/to_asm:
	$(call PRINT_INFO,building u-boot to_asm utility)
	gcc -o $@ $(BASE_DIR)/target/bootloaders/u-boot/to-asm.c

UBOOTBLOB_DEPS=$(BUILD_DIR)/u-boot-$(u-boot_VERSION)/ubootblob.lds $(BUILD_DIR)/u-boot-$(u-boot_VERSION)/to_asm
UBOOTBLOB_DEPS+=u-boot-host-install
UBOOTBLOB_DEPS+=kernel-host-install
ifeq (y,$(strip $(TSWO_UBOOT_COMBINE_WITH_KERNEL_AND_RFS)))
UBOOTBLOB_DEPS+=rfs-image-ext2
endif

rfs-image-ubootblob: $(UBOOTBLOB_DEPS)
	$(call PRINT_INFO,building u-boot blob)
	$(u-boot_DIR)/to_asm .text < $(u-boot_DDIR)/u-boot.bin > $(u-boot_DIR)/u-boot.s
	$(u-boot_DIR)/to_asm .uImage < $(IMAGES_DIR)/$(FINAL_KERNEL_SHORTFILENAME)-$(kernel_VERSION)$(kernel_EXTRAVERSION) > $(u-boot_DIR)/kernel.s
	$(TARGET_CROSS_PREFIX)gcc -c -o $(u-boot_DIR)/u-boot.o $(u-boot_DIR)/u-boot.s
	$(TARGET_CROSS_PREFIX)gcc -c -o $(u-boot_DIR)/kernel.o $(u-boot_DIR)/kernel.s
	$(TARGET_CROSS_PREFIX)ld -o $(IMAGES_DIR)/$(strip $(call UNQUOTE_VAR,$(TSWO_UBOOT_COMBINE_WITH_KERNEL_FILENAME))) -T \
		$(u-boot_DIR)/ubootblob.lds $(u-boot_DIR)/u-boot.o $(u-boot_DIR)/kernel.o


# add to packages list
ifeq (y,$(TSWO_BOOTLOADER_u-boot))
SOFTWARE+=u-boot
endif
ifeq (y,$(TSWO_HOSTTOOL_mkimage))
HOST_UTILITIES+=mkimage
endif
ifeq (y,$(strip $(TSWO_UBOOT_COMBINE_WITH_KERNEL)))
RFS_IMAGES+=ubootblob
endif

.PHONY: mkimage-fetch mkimage-unpack mkimage-patch mkimage-configure mkimage-build mkimage-rfs-install mkimage-package mkimage-clean mkimage-distclean mkimage-host-install rfs-image-ubootblob

# vim:set noexpandtab: 
