# Copyright (C) 2007-2009 Timesys Corporation
# ubifs RFS image make rules

.PHONY: rfs-image-ubifs rootfs-ubifs rootfs-ubi

$(IMAGES_DIR)/rfs/ubi.ini:
	@mkdir -p $(IMAGES_DIR)/rfs
ifeq ("",$(TSWO_RFS_FS_ubifs_UBI_CONFIG))	
	$(call PRINT_INFO,Creating default ubi configuration file)
	@mkdir -p $(IMAGES_DIR)/rfs
	@echo "[rootfs-volume]" > $@
	@echo "mode=ubi" >> $@
	@echo "image=$(IMAGES_DIR)/rfs/rootfs.ubifs" >> $@
	@echo "vol_id=0" >> $@
	@echo "vol_size=$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_FS_ubifs_VOL_SIZE)))" >> $@
	@echo "vol_type=dynamic" >> $@
	@echo "vol_name=rootfs" >> $@
	@echo "vol_flags=autoresize" >> $@
else
	$(call PRINT_INFO,fetching ubi configuration file)
	$(call FETCH_REMOTE,$(IMAGES_DIR)/rfs/,$(TSWO_RFS_FS_ubifs_UBI_CONFIG))
	-mv -f $(IMAGES_DIR)/rfs/$(notdir $(call UNQUOTE_VAR,$(TSWO_RFS_FS_ubifs_UBI_CONFIG))) $@
endif

rootfs-ubifs: $(BUILD_DIR)/.rfs.sh
	$(call PRINT_INFO,creating ubifs RFS image)
	@mkdir -p $(IMAGES_DIR)/rfs
	PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) /bin/bash -c "/bin/bash $(BUILD_DIR)/.rfs.sh; \
			mkfs.ubifs -r $(TSWO_RFS_INSTALL_DIR) \
				-o $(IMAGES_DIR)/rfs/rootfs.ubifs \
				-m $(TSWO_RFS_FS_ubifs_MIN_IO_SIZE) \
				-e $(TSWO_RFS_FS_ubifs_LOGICAL_ERASEBLOCK_SIZE) \
				-c $(TSWO_RFS_FS_ubifs_MAXERASEBLOCK) \
				$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_FS_ubifs_MKFS_OPTIONS)))"


rootfs-ubi: rootfs-ubifs $(IMAGES_DIR)/rfs/ubi.ini
	$(call PRINT_INFO,creating ubi RFS partition)
	@mkdir -p $(IMAGES_DIR)/rfs
	PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) /bin/bash -c \
			"ubinize \
				-o $(IMAGES_DIR)/rfs/rootfs.ubi \
				-s $(TSWO_RFS_FS_ubifs_SUBPAGE_SIZE) \
				-m $(TSWO_RFS_FS_ubifs_MIN_IO_SIZE) \
				-p \"$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_FS_ubifs_PHYSICAL_ERASEBLOCK_SIZE)))\" \
				$(strip $(call UNQUOTE_VAR,$(TSWO_RFS_FS_ubifs_UBINIZE_OPTIONS))) \
				$(IMAGES_DIR)/rfs/ubi.ini" 


ifeq (y,$(TSWO_RFS_FS_ubifs_UBINIZE))	
rfs-image-ubifs: rootfs-ubi
else
rfs-image-ubifs: rootfs-ubifs
endif

# add to RFS_IMAGES list
ifeq (y,$(TSWO_RFS_FS_ubifs))
RFS_IMAGES+=ubifs
endif


# vim:set noexpandtab: 
