# Copyright (C) 2007-2010 Timesys Corporation
# evas rules

# Define common macros for evas from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,evas))


evas_OPTIONAL_DEPS=fontconfig libpthread-stubs libxcb sdl Mesa qt-embedded-linux librsvg libtiff giflib edb DirectFB libxpm
evas_OPTIONAL_DEPS_TARGETS=$(foreach pkg,$(evas_OPTIONAL_DEPS), $(if $(TSWO_SOFTWARE_$(pkg)),$(pkg)-host-install,))
evas-patch: $(evas_OPTIONAL_DEPS_TARGETS)

ifneq (y,$(TSWO_SOFTWARE_librsvg))
evas_CONFIGURE_OPTIONS+=--enable-image-loader-svg=no
endif
ifneq (y,$(TSWO_SOFTWARE_libtiff))
evas_CONFIGURE_OPTIONS+=--enable-image-loader-tiff=no
endif
ifneq (y,$(TSWO_SOFTWARE_libxpm))
evas_CONFIGURE_OPTIONS+=--enable-image-loader-xpm=no
endif
ifneq (y,$(TSWO_SOFTWARE_libgif))
evas_CONFIGURE_OPTIONS+=--enable-image-loader-gif=no
endif

ifeq (y,$(strip $(TSWO_cortex_a8)))
evas_CONFIGURE_OPTIONS+=CFLAGS="-mfloat-abi=softfp -mfpu=neon"
endif

EVAS_HOST_INSTALL_DIR=$(BUILD_DIR)/evas-$(evas_VERSION)/evas-host-install
evas-host-build: eina-host-build eet-host-build evas-host-install $(BUILD_DIR)/evas-$(evas_VERSION)/.stamp_host_build
$(BUILD_DIR)/evas-$(evas_VERSION)/.stamp_host_build: 
	$(call PRINT_INFO,building evas host copy)
	mkdir -p $(@D)/evas-host-build
	$(INFLATE$(suffix $(evas_SOURCE))) $(evas_SRC_DL_DIR)/$(evas_SOURCE) | \
		$(TAR) -C $(@D)/evas-host-build $(TSWO_TAR_OPTIONS) -
	$(foreach patch,$(evas_PATCHES),$(call APPLY_PATCH,$(@D)/evas-host-build/$(evas_WORKINGDIR),$(evas_SRC_DL_DIR)/$(patch)))
	cd $(@D)/evas-host-build/$(evas_WORKINGDIR) && \
		PKG_CONFIG_PATH=$(EINA_HOST_INSTALL_DIR)/lib/pkgconfig:$(EET_HOST_INSTALL_DIR)/lib/pkgconfig \
		LDFLAGS=-L$(LIBJPEG_HOST_INSTALL_DIR)/lib \
		CPPFLAGS=-I$(LIBJPEG_HOST_INSTALL_DIR)/include \
		./configure \
			--prefix=$(EVAS_HOST_INSTALL_DIR) && \
		make && \
		make install
	@touch $@

$(BUILD_DIR)/evas-$(evas_VERSION)/.stamp_post_host_installed:
	@rm -f $(TSWO_HOST_INSTALL_DIR)/bin/{evas_cserve,evas_cserve_tool}
	@touch $@


# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_evas))
SOFTWARE+=evas
endif


# vim:set noexpandtab filetype=make: 
