# Copyright (C) 2007-2010 Timesys Corporation
# qt-embedded-linux rules

# Define common macros for qt-embedded-linux from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,qt-embedded-linux))

# Set Endian Flag
ifeq (y,$(TSWO_BIG_ENDIAN))
QT_EMBEDDED_ENDIAN='-big-endian'
else
QT_EMBEDDED_ENDIAN='-little-endian'
endif

# TSLIB Soft Dependency
ifeq (y,$(TSWO_SOFTWARE_tslib))
qt-embedded-linux-patch: tslib-host-install
qt-embedded-linux_CONFIGURE_OPTIONS+= -qt-mouse-tslib 
endif

# DBUS Soft Dependency
ifeq (y,$(TSWO_SOFTWARE_dbus))
qt-embedded-linux-patch: dbus-host-install
qt-embedded-linux_CONFIGURE_OPTIONS+= -dbus
endif

# Set/unset demo flag
ifeq (y,$(TSWO_qt-embedded-linux_BUILD_DEMOS))
qt-embedded-linux_CONFIGURE_OPTIONS+= -make demos 
else
qt-embedded-linux_CONFIGURE_OPTIONS+= -nomake demos 
endif

# Set/unset examples flag
ifeq (y,$(TSWO_qt-embedded-linux_BUILD_EXAMPLES))
qt-embedded-linux_CONFIGURE_OPTIONS+= -make examples 
else
qt-embedded-linux_CONFIGURE_OPTIONS+= -nomake examples 
endif

# broken webkit for ppc 4.6.0
qt-embedded-linux_BROKEN_WEBKIT_CONFIGURE_OPTIONS=
ifeq (4.6.0,$(qt-embedded-linux_VERSION))
qt-embedded-linux_BROKEN_WEBKIT_CONFIGURE_OPTIONS=-no-webkit
endif
qt-embedded-linux_CONFIGURE_OPTIONS+=$(qt-embedded-linux_BROKEN_WEBKIT_CONFIGURE_OPTIONS)

# Fix hard-coded cross-compiler values
$(BUILD_DIR)/qt-embedded-linux-$(qt-embedded-linux_VERSION)/.stamp_pre_configured:
	$(call PRINT_INFO,creating qt-embedded-linux $(qt-embedded-linux_VERSION) target spec files)
	@mkdir -p $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/
	echo "include(../../common/g++.conf)" > $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "include(../../common/linux.conf)" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "include(../../common/qws.conf)" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_CC                = $(TSWO_FULL_TARGET_NAME)-gcc" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_CXX               = $(TSWO_FULL_TARGET_NAME)-g++" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_LINK              = $(TSWO_FULL_TARGET_NAME)-g++" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_LINK_SHLIB        = $(TSWO_FULL_TARGET_NAME)-g++" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_AR                = $(TSWO_FULL_TARGET_NAME)-ar cqs" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_OBJCOPY           = $(TSWO_FULL_TARGET_NAME)-objcopy" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_STRIP             = $(TSWO_FULL_TARGET_NAME)-strip" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_CFLAGS           += $(TARGET_CFLAGS)" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_CXXFLAGS         += $(TARGET_CXXFLAGS)" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "QMAKE_LFLAGS           += $(TARGET_LDFLAGS)" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo "load(qt_config)" >> $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qmake.conf
	echo '#include "../../linux-g++/qplatformdefs.h"' > $(qt-embedded-linux_DDIR)/mkspecs/qws/linux-timesys-g++/qplatformdefs.h
	@touch $@

$(BUILD_DIR)/qt-embedded-linux-$(qt-embedded-linux_VERSION)/.stamp_configured:
	$(call PRINT_INFO,configuring qt-embedded-linux $(qt-embedded-linux_VERSION))
	$(call CONFIG_UPDATE,$(qt-embedded-linux_DDIR))
	cd $(qt-embedded-linux_DDIR) && rm -rf config.cache 2>/dev/null && \
		PATH=$(BUILD_PATH) \
		$(qt-embedded-linux_BUILD_OPTIONS) \
		./configure \
			-prefix /usr/qt \
			-bindir /usr/bin \
			-libdir /usr/lib \
			-sysconfdir /etc/qt \
			-datadir /usr/share \
			-headerdir /usr/include \
			-confirm-license \
			-embedded timesys \
			-force-pkg-config \
			$(QT_EMBEDDED_ENDIAN) \
		$(qt-embedded-linux_CONFIGURE_OPTIONS)
	@touch $@

$(BUILD_DIR)/qt-embedded-linux-$(qt-embedded-linux_VERSION)/.stamp_built:
	$(call PRINT_INFO,building qt-embedded-linux $(qt-embedded-linux_VERSION))
	cd $(qt-embedded-linux_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(qt-embedded-linux_BUILD_OPTIONS) \
		$(qt-embedded-linux_MAKE_CMD)
	@touch $@

$(BUILD_DIR)/qt-embedded-linux-$(qt-embedded-linux_VERSION)/.stamp_rfs_installed:
	$(call PRINT_INFO,installing qt-embedded-linux $(qt-embedded-linux_VERSION) to the RFS)
	@mkdir -p $(TSWO_RFS_INSTALL_DIR)
	cd $(qt-embedded-linux_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(qt-embedded-linux_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $(qt-embedded-linux_MAKE_CMD) INSTALL_ROOT=$(TSWO_RFS_INSTALL_DIR) install_subtargets install_translations 
	@touch $@

# Remove host tools from rfs installation
$(BUILD_DIR)/qt-embedded-linux-$(qt-embedded-linux_VERSION)/.stamp_post_rfs_installed: $(BUILD_DIR)/qt-embedded-linux-$(qt-embedded-linux_VERSION)/.stamp_rfs_installed
	cd $(qt-embedded-linux_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(qt-embedded-linux_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $(qt-embedded-linux_MAKE_CMD) INSTALL_ROOT=$(TSWO_RFS_INSTALL_DIR) sub-moc-uninstall_subtargets sub-rcc-uninstall_subtargets sub-uic-uninstall_subtargets
	@touch $@

$(BUILD_DIR)/qt-embedded-linux-$(qt-embedded-linux_VERSION)/.stamp_host_installed:
	$(call PRINT_INFO,installing qt-embedded-linux $(qt-embedded-linux_VERSION) to host)
	@mkdir -p $(TSWO_HOST_INSTALL_DIR)
	cd $(qt-embedded-linux_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(qt-embedded-linux_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $(qt-embedded-linux_MAKE_CMD) INSTALL_ROOT=$(TSWO_HOST_INSTALL_DIR) install
	$(call FIX_LIBTOOL_ARCHIVES,$(TSWO_HOST_INSTALL_DIR))
	$(call FIX_CONFIG_SCRIPTS,$(TSWO_HOST_INSTALL_DIR))
	$(call FIX_QT_MKSPECS,/usr/share/mkspecs,$(TSWO_HOST_INSTALL_DIR))
	@touch $@

$(BUILD_DIR)/qt-embedded-linux-$(qt-embedded-linux_VERSION)/.stamp_packaged:
	cd $(qt-embedded-linux_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(qt-embedded-linux_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $(qt-embedded-linux_MAKE_CMD) INSTALL_ROOT=$(qt-embedded-linux_PKG_INSTALL_DIR) install_subtargets install_translations
	# Remove host tools from package
	cd $(qt-embedded-linux_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(qt-embedded-linux_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $(qt-embedded-linux_MAKE_CMD) INSTALL_ROOT=$(TSWO_RFS_INSTALL_DIR) sub-moc-uninstall_subtargets sub-rcc-uninstall_subtargets sub-uic-uninstall_subtargets
	@touch $@

# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_qt-embedded-linux))
SOFTWARE+=qt-embedded-linux
endif

# vim:set noexpandtab filetype=make: 
