# Copyright (C) 2007-2010 Timesys Corporation
# DSPLink rules

TSWO_DSPLink_SOURCE=.stamp_fetched
DSPLink_INSTALL_DIR=$(strip $(call UNQUOTE_VAR,$(TSWO_DSPLink_INSTALL_DIR)))

DSPLink_BIOS_INSTALL_DIR=$(strip $(call UNQUOTE_VAR,$(TSWO_DSPLink_BIOS_INSTALL_DIR)))
DSPLink_CGTOOLS_INSTALL_DIR=$(strip $(call UNQUOTE_VAR,$(TSWO_DSPLink_CGTOOLS_INSTALL_DIR)))

ifeq (y,$(TSWO_DSPLink_SAMPLES))
DSPLink_XDCTOOLS_INSTALL_DIR=$(strip $(call UNQUOTE_VAR,$(TSWO_DSPLink_XDCTOOLS_INSTALL_DIR)))
DSPLink_SAMPLES=loop scale message readwrite mpcsxfer
endif

# Define common macros for DSPLink from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,DSPLink))

# same as the default, with SOURCE_URL removed
$(DSPLink_SRC_DL_DIR)/.stamp_fetched:
	$(call PRINT_INFO,fetching DSPLink $(DSPLink_VERSION))
	@mkdir -p $(@D) $(DSPLink_SRC_DL_DIR)
#       $(call FETCH_REMOTE,$(DSPLink_SRC_DL_DIR),$(DSPLink_SOURCE_URL))
	$(foreach patch,$(DSPLink_PATCHES),$(call FETCH_REMOTE,$(DSPLink_SRC_DL_DIR),$(DSPLink_URL)/$(patch)))
	$(foreach file,$(DSPLink_FILES),$(call FETCH_REMOTE,$(DSPLink_SRC_DL_DIR),$(DSPLink_URL)/$(file)))
	@touch $@

$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_unpacked:
	$(call PRINT_INFO,checking necessary files for DSPLink $(DSPLink_VERSION))
	@mkdir -p $(@D)
	@if [ ! -d $(TSWO_DSPLink_INSTALL_DIR) ]; then \
	echo "Cannot find DSPLink in location:" ;\
	echo "$(TSWO_DSPLink_INSTALL_DIR)" ;\
	echo "You must download DSPLink for your platform from TI and install it before building this package." ;\
	exit 1; \
	fi
	@if [ ! -d $(TSWO_DSPLink_BIOS_INSTALL_DIR) ]; then \
	echo "Cannot find TI DSP/BIOS in location:" ;\
	echo "$(TSWO_DSPLink_BIOS_INSTALL_DIR)" ;\
	echo "You must download DSP/BIOS from TI and install it before building this package." ;\
	exit 1; \
	fi
	@if [ ! -d $(TSWO_DSPLink_CGTOOLS_INSTALL_DIR) ]; then \
	echo "Cannot find TI Code Generation Tools in location:" ;\
	echo "$(TSWO_DSPLink_CGTOOLS_INSTALL_DIR)" ;\
	echo "You must download Code Generation Tools from TI and install it before building this package." ;\
	exit 1; \
	fi
	@if [ ! -d $(TSWO_DSPLink_XDCTOOLS_INSTALL_DIR) ]; then \
	echo "Cannot find TI Code Generation Tools in location:" ;\
	echo "$(TSWO_DSPLink_XDCTOOLS_INSTALL_DIR)" ;\
	echo "You must download Code Generation Tools from TI and install it before building this package." ;\
	exit 1; \
	fi
	@touch $@


$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_patched:
	@touch $@

$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_configured:
	$(call PRINT_INFO,configuring DSPLink $(DSPLink_VERSION))
#	$(call CONFIG_UPDATE,$(DSPLink_DDIR))
	cd $(TSWO_DSPLink_INSTALL_DIR) && \
	DSPLINK=$(DSPLink_INSTALL_DIR) \
	$(PERL) config/bin/dsplinkcfg.pl \
	--platform=$(TSWO_DSPLink_PLATFORM) \
	--nodsp=$(TSWO_DSPLink_NODSP) \
	--dspcfg_0=$(TSWO_DSPLink_DSPCFG_0) \
	--dspos_0=$(TSWO_DSPLink_DSPOS_0) \
	--gppos=$(TSWO_DSPLink_GPPOS) \
	--comps=$(TSWO_DSPLink_COMPS) \
	--DspTskMode=$(TSWO_DSPLink_DSPTSKMODE)
	@touch $@
$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_post_configured:
	cd $(TSWO_DSPLink_INSTALL_DIR)/dsp && \
		$(TSWO_DSPLink_XDCTOOLS_INSTALL_DIR)/xdc clean
	cd $(TSWO_DSPLink_INSTALL_DIR)/dsp && \
		$(TSWO_DSPLink_XDCTOOLS_INSTALL_DIR)/xdc .interfaces
	cd $(TSWO_DSPLink_INSTALL_DIR)/gpp && \
		$(TSWO_DSPLink_XDCTOOLS_INSTALL_DIR)/xdc clean
	cd $(TSWO_DSPLink_INSTALL_DIR)/gpp && \
		$(TSWO_DSPLink_XDCTOOLS_INSTALL_DIR)/xdc .interfaces
	@touch $@

ifeq (y,$(TSWO_DSPLink_DEBUG))
DSPLink_DEBUG="debug"
DSPLink_BINDIR="DEBUG"
else
DSPLink_DEBUG="release"
DSPLink_BINDIR="RELEASE"
endif

$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_built:
	$(call PRINT_INFO,building DSPLink $(DSPLink_VERSION))
	cd $(DSPLink_INSTALL_DIR)/gpp/src && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
		$(DSPLink_BUILD_OPTIONS) \
		$(DSPLink_MAKE_CMD) \
		$(DSPLink_DEBUG) \
		DSPLINK=$(DSPLink_INSTALL_DIR) \
		BASE_BUILDOS=$(BUILD_DIR)/linux-$(TSWO_kernel_VERSION) \
		BASE_CGTOOLS=$(BUILD_DIR)/toolchain/bin \
		COMPILER=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-gcc \
		LD=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-ld \
		LINKER=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-gcc \
		ARCHIVER1=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-ld \
		ARCHIVER=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-ar \
		OSINC_TARGET=$(BUILD_DIR)/toolchain/include \
		OSINC_PLATFORM=$(BUILD_DIR)/toolchain/lib/gcc/$(TSWO_FULL_TARGET_NAME)/$(TSWO_GCC_VERSION)/include \
		KERNEL_DIR=$(BUILD_DIR)/linux-$(TSWO_kernel_VERSION) \
		MAKE_OPTS="ARCH=arm CROSS_COMPILE=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-	"
#	DSP-side
	cd $(DSPLink_INSTALL_DIR)/dsp/src && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
		$(DSPLink_BUILD_OPTIONS) \
		$(DSPLink_MAKE_CMD) \
		$(DSPLink_DEBUG) \
		DSPLINK=$(DSPLink_INSTALL_DIR) \
		BASE_CGTOOLS=$(DSPLink_CGTOOLS_INSTALL_DIR) \
		BASE_SABIOS=$(DSPLink_BIOS_INSTALL_DIR) \
		XDCTOOLS_DIR=$(TSWO_DSPLink_XDCTOOLS_INSTALL_DIR)
#Build samples if requested
ifeq (y,$(TSWO_DSPLink_SAMPLES))
	cd $(DSPLink_INSTALL_DIR)/dsp/src/samples && \
		$(DSPLink_XDCTOOLS_INSTALL_DIR)/gmake $(DSPLink_DEBUG) \
		DSPLINK=$(DSPLink_INSTALL_DIR) \
		BASE_CGTOOLS=$(DSPLink_CGTOOLS_INSTALL_DIR) \
		BASE_SABIOS=$(DSPLink_BIOS_INSTALL_DIR) \
		XDCTOOLS_DIR=$(TSWO_DSPLink_XDCTOOLS_INSTALL_DIR)
	cd $(DSPLink_INSTALL_DIR)/gpp/src/samples && \
		DSPLINK=$(DSPLink_INSTALL_DIR) \
		$(DSPLink_XDCTOOLS_INSTALL_DIR)/gmake $(DSPLink_DEBUG) \
		BASE_BUILDOS=$(BUILD_DIR)/linux-$(TSWO_kernel_VERSION) \
		BASE_CGTOOLS=$(BUILD_DIR)/toolchain/bin \
		COMPILER=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-gcc \
		LD=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-ld \
		LINKER=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-gcc \
		ARCHIVER1=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-ld \
		ARCHIVER=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-ar \
		OSINC_TARGET=$(BUILD_DIR)/toolchain/include \
		OSINC_PLATFORM=$(BUILD_DIR)/toolchain/lib/gcc/$(TSWO_FULL_TARGET_NAME)/$(TSWO_GCC_VERSION)/include \
		KERNEL_DIR=$(BUILD_DIR)/linux-$(TSWO_kernel_VERSION) \
		MAKE_OPTS="ARCH=arm CROSS_COMPILE=$(BUILD_DIR)/toolchain/bin/$(TSWO_FULL_TARGET_NAME)-	"
endif
	@touch $@

# DSPLink-rfs-install is a frontend for:
#
#$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_pre_rfs_installed:
#	@touch $@
$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_rfs_installed:
	$(call PRINT_INFO,installing DSPLink $(DSPLink_VERSION) to the RFS)
	@mkdir -p $(TSWO_RFS_INSTALL_DIR)/opt/dsplink
	cd $(DSPLink_INSTALL_DIR) && \
		cp -f ./gpp/export/BIN/Linux/OMAPL138/$(DSPLink_BINDIR)/dsplinkk.* $(TSWO_RFS_INSTALL_DIR)/opt/dsplink
ifeq (y,$(TSWO_DSPLink_SAMPLES))
	cd $(DSPLink_INSTALL_DIR) && \
		for sample in $(DSPLink_SAMPLES); do \
		mkdir -p $(TSWO_RFS_INSTALL_DIR)/opt/dsplink/$$sample ; \
		cp -f ./gpp/export/BIN/Linux/$(TSWO_DSPLink_PLATFORM)/$(DSPLink_BINDIR)/$${sample}gpp $(TSWO_RFS_INSTALL_DIR)/opt/dsplink/$$sample ; \
		cp -f ./dsp/export/BIN/DspBios/$(TSWO_DSPLink_PLATFORM)/OMAPL138GEM_0/$(DSPLink_BINDIR)/$${sample}.out $(TSWO_RFS_INSTALL_DIR)/opt/dsplink/$$sample ; \
		done
endif
	@touch $@

$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_host_installed:
	$(call PRINT_INFO,installing DSPLink $(DSPLink_VERSION) to host)
	@echo "DSPLink headers/libs will not be installed in the toolchain. Use the makefiles and headers included within DSPLink to build applications."
	@touch $@

$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_pre_packaged:
	$(call PRINT_INFO,packaging DSPLink $(DSPLink_VERSION))
	@mkdir -p $(DSPLink_PKG_INSTALL_DIR)/opt/dsplink
	@touch $@
$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_packaged:
	cd $(DSPLink_INSTALL_DIR) && \
		cp -f ./gpp/export/BIN/Linux/OMAPL138/$(DSPLink_BINDIR)/dsplinkk.* $(DSPLink_PKG_INSTALL_DIR)/opt/dsplink
ifeq (y,$(TSWO_DSPLink_SAMPLES))
	cd $(DSPLink_INSTALL_DIR) && \
		for sample in $(DSPLink_SAMPLES); do \
		mkdir -p $(DSPLink_PKG_INSTALL_DIR)/opt/dsplink/$$sample ; \
		cp -f ./gpp/export/BIN/Linux/$(TSWO_DSPLink_PLATFORM)/$(DSPLink_BINDIR)/$${sample}gpp $(TSWO_PKG_INSTALL_DIR)/opt/dsplink/$$sample ; \
		cp -f ./dsp/export/BIN/DspBios/$(TSWO_DSPLink_PLATFORM)/OMAPL138GEM_0/$(DSPLink_BINDIR)/$${sample}.out $(DSPLink_PKG_INSTALL_DIR)/opt/dsplink/$$sample ; \
		done
endif
	@touch $@

# Since it is an external directory, (dist)clean must be specially handled
DSPLink-distclean: DSPLink-clean

$(BUILD_DIR)/DSPLink-$(DSPLink_VERSION)/.stamp_cleaned:
	$(call PRINT_INFO,cleaning DSPLink $(DSPLink_VERSION))
	cd $(DSPLink_INSTALL_DIR)/gpp/src/ && \
		DSPLINK=$(DSPLink_INSTALL_DIR) \
		$(DSPLink_MAKE_CMD) clean
	cd $(DSPLink_INSTALL_DIR)/dsp/src/ && \
		DSPLINK=$(DSPLink_INSTALL_DIR) \
		$(DSPLink_MAKE_CMD) clean
	cd $(BUILD_DIR)/DSPLink-$(DSPLink_VERSION) && \
		rm -f .stamp_{*built,*rfs_installed,*host_installed,*packaged}

# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_DSPLink))
SOFTWARE+=DSPLink
endif


# vim:set noexpandtab filetype=make:
