# Copyright (C) 2007-2010 Timesys Corporation
# apache-httpd rules

# Define common macros for apache-httpd from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,apache-httpd))

ifeq (y,$(strip $(TSWO_SOFTWARE_openssl)))
apache-httpd-patch: openssl-host-install
apache-httpd_CONFIGURE_OPTIONS+=--enable-ssl
endif

APACHE_HOST_BUILD_DIR=$(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/apache_host_build_dir
APACHE_HOST_BUILD_PATH=$(APACHE_HOST_BUILD_DIR)/bin:$(APACHE_HOST_BUILD_DIR)/sbin

$(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_configured:
	$(call PRINT_INFO,configuring apache-httpd $(apache-httpd_VERSION))
	$(call CONFIG_UPDATE,$(apache-httpd_DDIR))
	cd $(apache-httpd_DDIR) && rm -rf config.cache 2>/dev/null && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
		LTFLAGS='--tag=CC' \
        $(apache-httpd_BUILD_OPTIONS) \
		./configure \
			--target=$(TSWO_FULL_TARGET_NAME) \
			--host=$(TSWO_FULL_TARGET_NAME) \
			--build=$(TSWO_BUILD_NAME) \
			$(TARGET_CONFIGURE_OPTIONS) \
        	$(apache-httpd_CONFIGURE_OPTIONS)
	@touch $@

$(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_post_host_installed:
	@mv -f $(TSWO_HOST_INSTALL_DIR)/usr/sbin/* $(TSWO_HOST_INSTALL_DIR)/usr/bin
	@rm -f $(TSWO_HOST_INSTALL_DIR)/usr/bin/{ab,apachectl,checkgid,dbmmanage,htcacheclean,htdbm,htdigest,htpasswd,httxt2dbm,logresolve,rotatelogs}
	@$(SED) -i -re 's|(installbuilddir = ")([^"]+)|\1$(TSWO_HOST_INSTALL_DIR)\2|' $(TSWO_HOST_INSTALL_DIR)/usr/bin/apxs
	@$(SED) -i -re 's|(/var/www/build/)|$(TSWO_HOST_INSTALL_DIR)\1|' $(TSWO_HOST_INSTALL_DIR)/var/www/build/config_vars.mk
	@$(SED) -i -re 's|^(bindir = )\$$\{prefix\}/bin|\1$(TSWO_HOST_INSTALL_DIR)/bin|' $(TSWO_HOST_INSTALL_DIR)/var/www/build/config_vars.mk
	@$(SED) -i -re 's|^(sbindir = )\$$\{prefix\}/sbin|\1$(TSWO_HOST_INSTALL_DIR)/bin|' $(TSWO_HOST_INSTALL_DIR)/var/www/build/config_vars.mk
	-@cd $(TSWO_HOST_INSTALL_DIR)/usr/bin/ && \
		mv -f apxs apxs-config && \
		ln -s apxs-config apxs
	-@cd $(TSWO_HOST_INSTALL_DIR)/var/www/build/ && \
		mv -f config_vars.mk config_vars.mk-config
		ln -s config_vars.mk-config config_vars.mk
	@touch $@

$(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_apr_fake:
	$(call PRINT_INFO,building fake apr)
	$(INFLATE$(suffix $(apr_SOURCE))) $(apr_SRC_DL_DIR)/$(apr_SOURCE) | \
		$(TAR) -C $(@D) $(TSWO_TAR_OPTIONS) -
	$(foreach patch,$(apr_PATCHES),$(call APPLY_PATCH,$(@D)$(apr_WORKINGDIR),$(apr_SRC_DL_DIR)/$(patch)))
	cd $(@D)/$(apr_WORKINGDIR) && \
		./configure \
			--prefix=$(APACHE_HOST_BUILD_DIR) && \
		make && \
		make install
	@touch $@

$(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_expat_fake:
	$(call PRINT_INFO,building fake expat)
	$(INFLATE$(suffix $(expat_SOURCE))) $(expat_SRC_DL_DIR)/$(expat_SOURCE) | \
		$(TAR) -C $(@D) $(TSWO_TAR_OPTIONS) -
	$(foreach patch,$(expat_PATCHES),$(call APPLY_PATCH,$(@D)$(apr_WORKINGDIR),$(expat_SRC_DL_DIR)/$(patch))) 
	cd $(@D)/$(expat_WORKINGDIR) && \
		./configure \
			--prefix=$(APACHE_HOST_BUILD_DIR) && \
		make && \
		make install
	@touch $@

$(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_apr-util_fake: $(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_apr_fake $(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_expat_fake
	$(call PRINT_INFO,building fake apr-util)
	$(INFLATE$(suffix $(apr-util_SOURCE))) $(apr-util_SRC_DL_DIR)/$(apr-util_SOURCE) | \
		$(TAR) -C $(@D) $(TSWO_TAR_OPTIONS) -
	$(foreach patch,$(apr-util_PATCHES),$(call APPLY_PATCH,$(@D)$(apr_WORKINGDIR),$(apr-util_SRC_DL_DIR)/$(patch))) 
	cd $(@D)/$(apr-util_WORKINGDIR) && \
		./configure \
			--prefix=$(APACHE_HOST_BUILD_DIR) \
			--with-apr=$(APACHE_HOST_BUILD_DIR) \
			--with-expat=$(APACHE_HOST_BUILD_DIR) && \
		make && \
		make install
	@touch $@

$(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_pre_built: $(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_apr_fake $(BUILD_DIR)/apache-httpd-$(apache-httpd_VERSION)/.stamp_apr-util_fake
	$(call PRINT_INFO,prebuilding gen_test_char host utility)
	cd $(apache-httpd_DDIR) && \
		PATH=$(APACHE_HOST_BUILD_PATH):$(BUILD_PATH) \
		make -C server gen_test_char util_debug.o util_debug.lo
	cd $(apache-httpd_DDIR)/server && \
		$(HOSTCC) -DLINUX=2 -D_REENTRANT -D_GNU_SOURCE -I. -I../os/unix -I../server/mpm/prefork -I../modules/http -I../modules/filters -I../modules/proxy -I../include -I../modules/generators -I../modules/mappers -I../modules/database -I../modules/proxy/../generators -I../modules/ssl -I../modules/dav/main -I$(APACHE_HOST_BUILD_DIR)/include/apr-1 -c gen_test_char.c -o gen_test_char.o && \
		$(HOSTCC) -DLINUX=2 -D_REENTRANT -D_GNU_SOURCE -I. -I../os/unix -I../server/mpm/prefork -I../modules/http -I../modules/filters -I../modules/proxy -I../include -I../modules/generators -I../modules/mappers -I../modules/database -I../modules/proxy/../generators -I../modules/ssl -I../modules/dav/main -I$(APACHE_HOST_BUILD_DIR)/include/apr-1 -c util_debug.c -o util_debug.o && \
		$(HOSTCC)  -o gen_test_char gen_test_char.o util_debug.o && \
		cp -f gen_test_char gen_test_char_native
	cd $(apache-httpd_DDIR)/server && \
		$(SED) -i -re 's/(\.\/gen_test_char)/\1_native/' Makefile
	cd $(apache-httpd_DDIR)/server && \
		rm -f ./gen_test_char.o ./util_debug.o ./util_debug.lo
	cd $(apache-httpd_DDIR) && \
		PATH=$(APACHE_HOST_BUILD_PATH):$(BUILD_PATH) \
		make -C server util_debug.o util_debug.lo
	@touch $@


# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_apache-httpd))
SOFTWARE+=apache-httpd
endif


# vim:set noexpandtab filetype=make: 
