# Copyright (C) 2007-2010 Timesys Corporation
# openssl rules

# Define common macros for this openssl from include/common.mk
$(eval $(call COMMON_SETUP,openssl))

openssl_OPENSSLDIR=/etc/ssl
openssl_ENGINESDIR=/usr/lib/openssl/engines

#@cd $(openssl_DDIR) && \
#	$(openssl_MAKE_CMD) depend
$(BUILD_DIR)/openssl-$(openssl_VERSION)/.stamp_configured:
	$(call PRINT_INFO,configuring openssl)
	cd $(openssl_DDIR) && \
		$(openssl_BUILD_OPTIONS) \
		PATH=$(BUILD_PATH) \
		./Configure linux-$(strip $(call UNQUOTE_VAR,$(TSWO_openssl_ARCH))) \
			--prefix=/usr \
			--openssldir=$(openssl_OPENSSLDIR) -L$(TSWO_HOST_INSTALL_DIR)/lib -ldl \
			--enginesdir=$(openssl_ENGINESDIR) \
			-I$(TSWO_HOST_INSTALL_DIR)/usr/include $(openssl_CONFIGURE_OPTIONS) threads \
			shared no-idea no-mdc2 no-rc5
	@touch $@

$(BUILD_DIR)/openssl-$(openssl_VERSION)/.stamp_built:
	$(call PRINT_INFO,building openssl)
	cd $(openssl_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(openssl_MAKE_CMD) CC=$(TSWO_FULL_TARGET_NAME)-gcc all build-shared do_linux-shared
	@touch $@

#@cd $(openssl_DDIR) && \
#	cp -fa libssl* libcrypto* $(openssl_PKG_INSTALL_DIR)/lib
#@(cd $(openssl_PKG_INSTALL_DIR)/lib/ && ln -s libssl.so.0.* libssl.so.0)
#@(cd $(openssl_PKG_INSTALL_DIR)/lib/ && ln -s libcrypto.so.0.* libcrypto.so.0)
$(BUILD_DIR)/openssl-$(openssl_VERSION)/.stamp_packaged:
	mkdir -p $(openssl_PKG_INSTALL_DIR)$(openssl_ENGINESDIR)
	mkdir -p $(openssl_PKG_INSTALL_DIR)/usr/share/man
	PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) $(openssl_MAKE_CMD) -C $(openssl_DDIR) \
			CC=$(TSWO_FULL_TARGET_NAME)-gcc \
			INSTALLTOP=/usr \
			INSTALL_PREFIX=$(openssl_PKG_INSTALL_DIR) \
			install
	for m in 1 3 5 7;do \
		mkdir -p $(openssl_PKG_INSTALL_DIR)/usr/share/man/man$${m}; \
		mv -f $(openssl_PKG_INSTALL_DIR)$(openssl_OPENSSLDIR)/man/man$${m}/* $(openssl_PKG_INSTALL_DIR)/usr/share/man/man$${m}/; \
		done
	rm -rf $(openssl_PKG_INSTALL_DIR)$(openssl_OPENSSLDIR)/man
	rmdir $(openssl_PKG_INSTALL_DIR)/usr/lib/engines
	@touch $@

$(BUILD_DIR)/openssl-$(openssl_VERSION)/.stamp_post_host_installed:
	rm -f $(TSWO_HOST_INSTALL_DIR)/bin/openssl
	@touch $@

#@cd $(openssl_DDIR) && \
#	cp -fa libssl* libcrypto* $(TSWO_HOST_INSTALL_DIR)/lib
#@(cd $(TSWO_HOST_INSTALL_DIR)/lib/ && ln -s libssl.so.0.* libssl.so.0)
#@(cd $(TSWO_HOST_INSTALL_DIR)/lib/ && ln -s libcrypto.so.0.* libcrypto.so.0)
$(BUILD_DIR)/openssl-$(openssl_VERSION)/.stamp_host_installed:
	$(call PRINT_INFO,installing openssl to the host)
	mkdir -p $(TSWO_HOST_INSTALL_DIR)$(openssl_ENGINESDIR)
	mkdir -p $(TSWO_HOST_INSTALL_DIR)/usr/share/man
	PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) $(openssl_MAKE_CMD) -C $(openssl_DDIR) \
			CC=$(TSWO_FULL_TARGET_NAME)-gcc \
			INSTALLTOP=/ \
			INSTALL_PREFIX=$(TSWO_HOST_INSTALL_DIR) \
			install
	rmdir $(TSWO_HOST_INSTALL_DIR)/lib/engines
	rm -rf $(TSWO_HOST_INSTALL_DIR)$(openssl_OPENSSLDIR)
	$(call FIX_LIBTOOL_ARCHIVES,$(TSWO_HOST_INSTALL_DIR))
	$(call FIX_CONFIG_SCRIPTS,$(TSWO_HOST_INSTALL_DIR))
	@touch $@

#@cd $(openssl_DDIR) && \
#	cp -fa libssl* libcrypto* $(TSWO_RFS_INSTALL_DIR)/usr/lib
#@(cd $(TSWO_RFS_INSTALL_DIR)/usr/lib/ && ln -s libssl.so.0.* libssl.so.0)
#@(cd $(TSWO_RFS_INSTALL_DIR)/usr/lib/ && ln -s libcrypto.so.0.* libcrypto.so.0)
$(BUILD_DIR)/openssl-$(openssl_VERSION)/.stamp_rfs_installed:
	$(call PRINT_INFO,installing openssl to the RFS)
	mkdir -p $(TSWO_RFS_INSTALL_DIR)$(openssl_ENGINESDIR)
	mkdir -p $(TSWO_RFS_INSTALL_DIR)/usr/share/man
	PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) $(openssl_MAKE_CMD) -C $(openssl_DDIR) \
			CC=$(TSWO_FULL_TARGET_NAME)-gcc \
			INSTALLTOP=/usr \
			INSTALL_PREFIX=$(TSWO_RFS_INSTALL_DIR) \
			install
	for m in 1 3 5 7;do \
		mkdir -p $(TSWO_RFS_INSTALL_DIR)/usr/share/man/man$${m}; \
		mv -f $(TSWO_RFS_INSTALL_DIR)$(openssl_OPENSSLDIR)/man/man$${m}/* $(TSWO_RFS_INSTALL_DIR)/usr/share/man/man$${m}/; \
		done
	rm -rf $(TSWO_RFS_INSTALL_DIR)$(openssl_OPENSSLDIR)/man
	rmdir $(TSWO_RFS_INSTALL_DIR)/usr/lib/engines
	@touch $@

# add to software list
ifeq (y,$(TSWO_SOFTWARE_openssl))
SOFTWARE+=openssl
endif


# vim:set noexpandtab: 
