# Copyright (C) 2007-2010 Timesys Corporation
# perl rules
# adapted from http://marc.info/?l=uclinux-dev&m=103472995719915&w=2

# Define common macros for this perl from include/common.mk
$(eval $(call COMMON_SETUP,perl))



#############################################################
# perl
#

PERL_CONFIG=$(perl_SRC_DL_DIR)/perl_config

$(perl_SRC_DL_DIR)/perl_config:
	$(call PRINT_INFO,fetching perl configuration)
	$(call FETCH_REMOTE,$(perl_SRC_DL_DIR),$(TSWO_PERL_CONFIG))
	mv -f $(perl_SRC_DL_DIR)/$(notdir $(strip $(call UNQUOTE_VAR,$(TSWO_PERL_CONFIG)))) $@
	$(SED) -i -e 's/TSWO_FULL_TARGET_NAME/$(TSWO_FULL_TARGET_NAME)/' -e 's/TSWO_ARCH/$(strip $(call UNQUOTE_VAR,$(TSWO_ARCH)))/' $@

# before configuring for the target, build a native miniperl, generate_uudmap
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_pre_configured: $(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_patched
	$(call PRINT_INFO,building miniperl $(perl_VERSION) for host)
	@cd $(perl_DDIR) && \
		if [ -e Makefile -o -e makefile ]; then make distclean; fi
	@cd $(perl_DDIR) && \
		sh Configure -des
	@cd $(perl_DDIR) && \
		$(MAKE) miniperl
	@cd $(perl_DDIR) && \
		cp -f miniperl miniperl.native && \
		if [ -e generate_uudmap ]; then \
		  cp -f generate_uudmap generate_uudmap.native; \
		fi && \
		cp -f config.sh config.sh.native
	@cd $(perl_DDIR) && \
                $(MAKE) distclean
	@touch $@

ifeq (y,$(TSWO_PERL_USE_THREADS))
PERL_THREAD_CONFIGURE_OPTIONS= -Dusethreads -Duseithreads
else
PERL_THREAD_CONFIGURE_OPTIONS= -Uusethreads -Uuseithreads
endif
ifeq (y,$(TSWO_HAS_LARGE_FILE))
PERL_LARGE_FILE_CONFIGURE_OPTIONS= -Duselargefiles
else
PERL_LARGE_FILE_CONFIGURE_OPTIONS= -Uuselargefiles
endif

$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_configured: $(PERL_CONFIG)
	$(call PRINT_INFO,configuring perl $(perl_VERSION))
	cd $(perl_DDIR) && \
		cp -f $(PERL_CONFIG) config.sh
	cd $(perl_DDIR) && \
		sh Configure -S 
	$(SED) -i -re 's,./perl installman,echo disabled perl installman,g' $(perl_DDIR)/Makefile
	@touch $@

# Fool the makefile into using our native mini-perl by building in stages
# and replacing the target one with the native one after each step.
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_built:
	$(call PRINT_INFO,building perl $(perl_VERSION))
	rm -f $(perl_DDIR)/miniperl $(perl_DDIR)/generate_uudmap
	cd $(perl_DDIR) && \
		if [ -e generate_uudmap.native ]; then \
		  PATH=$(BUILD_PATH) \
                  $(TARGET_ALIASES) \
                  $(TARGET_BUILD_OPTIONS) \
                  $(MAKE) generate_uudmap && \
		  mv -f generate_uudmap generate_uudmap.target && \
		  cp -f generate_uudmap.native generate_uudmap ; \
		fi
	cd $(perl_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(TARGET_BUILD_OPTIONS) \
		$(MAKE) miniperl
	cd $(perl_DDIR) && \
		mv -f miniperl miniperl.target && \
		cp -f miniperl.native miniperl
	cd $(perl_DDIR) && \
                PATH=$(BUILD_PATH) \
                $(TARGET_ALIASES) \
                $(TARGET_BUILD_OPTIONS) \
                $(MAKE)
	cd $(perl_DDIR) && \
                mv -f perl perl.target
	@touch $@

$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_packaged:
	cd $(perl_DDIR) && \
		cp -f miniperl.native perl && \
		PATH=$(BUILD_PATH) \
		$(MAKE) install DESTDIR=$(perl_PKG_INSTALL_DIR)
	cp -f $(perl_DDIR)/perl.target $(perl_PKG_INSTALL_DIR)/usr/bin/perl
	find $(perl_PKG_INSTALL_DIR) -name '*NDBM*' | xargs rm -rfv
	find $(perl_PKG_INSTALL_DIR) -type f -name '*.bs' -a -empty -exec rm -f {} \;
	@touch $@
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_host_installed:
	@touch $@
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_rfs_installed:
	$(call PRINT_INFO,installing perl $(perl_VERSION) to the RFS)
	cd $(perl_DDIR) && \
		cp -f miniperl.native perl && \
		PATH=$(BUILD_PATH) \
		$(MAKE) install DESTDIR=$(TSWO_RFS_INSTALL_DIR)
	cp -f $(perl_DDIR)/perl.target $(TSWO_RFS_INSTALL_DIR)/usr/bin/perl
	find $(TSWO_RFS_INSTALL_DIR) -name '*NDBM*' | xargs rm -rfv
	find $(TSWO_RFS_INSTALL_DIR) -type f -name '*.bs' -a -empty -exec rm -f {} \;
	@touch $@

$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_remove_docs_packaged: DESTDIR=$(perl_PKG_INSTALL_DIR)
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_remove_docs_rfs_installed: DESTDIR=$(TSWO_RFS_INSTALL_DIR)
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_post_packaged: $(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_remove_docs_packaged
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_post_rfs_installed: $(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_remove_docs_rfs_installed
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_remove_docs_packaged $(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_remove_docs_rfs_installed:
	rm -f $(DESTDIR)/usr/bin/{pod2latex,instmodsh,pod2usage,pod2html,pod2man,perldoc,podselect,piconv,pod2text,podchecker,h2ph,prove}
	find $(DESTDIR)/usr/lib/perl/ -name '*.pod' -exec rm -f {} \;
	@touch $@

##############################################################
# microperl
#
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_configured:
	$(SED) -i \
		-e "s,^archname='.*',archname='$(TSWO_ARCH)-linux'," \
		-e "s,^archlib='.*',archlib='/usr/lib/perl5/$(perl_VERSION)'," \
		-e "s,^archlibexp='.*',archlib='/usr/lib/perl5/$(perl_VERSION)'," \
		-e "s,^bin='.*',bin='/usr/bin'," \
		-e "s,^privlib='.*',privlib='/usr/lib/perl5/$(perl_VERSION)'," \
		-e "s,^privlibexp='.*',privlibexp='/usr/lib/perl5/$(perl_VERSION)'," \
		-e "s,^scriptdir='.*',scriptdir='/usr/bin'," \
		-e "s,^scriptdirexp='.*',scriptdirexp='/usr/bin'," \
		$(perl_DDIR)/uconfig.sh
	chmod 644 $(perl_DDIR)/uconfig.h
	cd $(perl_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(MAKE) -f Makefile.micro regen_uconfig
	@touch $@

$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_built:
	$(call PRINT_INFO,building microperl $(perl_VERSION))
	-cd $(perl_DDIR) && \
		PATH=$(BUILD_PATH) \
		make -f Makefile.micro generate_uudmap
	cd $(perl_DDIR) && \
		PATH=$(BUILD_PATH) \
		CC="$(TSWO_FULL_TARGET_NAME)-gcc" OPTIMIZE=$(TARGET_BUILD_OPTIONS) \
		make -f Makefile.micro
	@touch $@

TSWO_perl_MICROPERL_MODULES?=Attribute/Handlers.pm attributes.pm AutoLoader.pm bytes.pm Carp.pm constant.pm DirHandle.pm Dumpvalue.pm Exporter.pm  File/Basename.pm File/Compare.pm File/DosGlob.pm File/Path.pm Getopt/Std.pm Hash/Util.pm integer.pm IPC/Open2.pm IPC/Open3.pm NEXT.pm overload.pm PerlIO.pm SelfLoader.pm strict.pm subs.pm Symbol.pm UNIVERSAL.pm vars.pm warnings.pm
microperl_PKG_INSTALL_DIR=$(PACKAGE_DIR)/microperl_install
microperl_PKG_NAME=$(PACKAGE_DIR)/microperl-$(perl_VERSION)-$(TSWO_FULL_TARGET_NAME)-1.tgz
$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_packaged:
	$(call PRINT_INFO,packaging microperl $(perl_VERSION))
	mkdir -p $(microperl_PKG_INSTALL_DIR)/usr/lib/perl5/$(perl_VERSION)
	mkdir -p $(microperl_PKG_INSTALL_DIR)/usr/bin/
	cd $(perl_DDIR) && \
		cp -pdf microperl $(microperl_PKG_INSTALL_DIR)/usr/bin/
	if [ -e $(microperl_PKG_INSTALL_DIR)/usr/bin/perl ]; then \
		mv -f $(microperl_PKG_INSTALL_DIR)/usr/bin/perl $(microperl_PKG_INSTALL_DIR)/usr/bin/perl.full;fi
	cd $(microperl_PKG_INSTALL_DIR)/usr/bin/ && \
		ln -s microperl perl
	cd $(perl_DDIR) && \
		for mod in $(strip $(call UNQUOTE_VAR,$(TSWO_perl_MICROPERL_MODULES)));do mkdir -p $(microperl_PKG_INSTALL_DIR)/usr/lib/perl5/$(perl_VERSION)/`dirname $$mod`; cp -pdf lib/$$mod $(microperl_PKG_INSTALL_DIR)/usr/lib/perl5/$(perl_VERSION)/`dirname $$mod`/;done
	$(call CREATE_PACKAGE, microperl,$(microperl_PKG_INSTALL_DIR),$(microperl_PKG_NAME),$(perl_VERSION),$(perl_BUILDNUM),)
	rm -rf $(microperl_PKG_INSTALL_DIR)
	@touch $@

$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_host_installed:
	@touch $@

$(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_rfs_installed:
	$(call PRINT_INFO,installing microperl $(perl_VERSION) to the RFS)
	mkdir -p $(TSWO_RFS_INSTALL_DIR)/usr/lib/perl5/$(perl_VERSION)
	mkdir -p $(TSWO_RFS_INSTALL_DIR)/usr/bin/
	cd $(perl_DDIR) && \
		cp -pdf microperl $(TSWO_RFS_INSTALL_DIR)/usr/bin/
	if [ -e $(TSWO_RFS_INSTALL_DIR)/usr/bin/perl ]; then \
		mv -f $(TSWO_RFS_INSTALL_DIR)/usr/bin/perl $(TSWO_RFS_INSTALL_DIR)/usr/bin/perl.full;fi
	cd $(TSWO_RFS_INSTALL_DIR)/usr/bin/ && \
		ln -s microperl perl
	cd $(perl_DDIR) && \
		for mod in $(strip $(call UNQUOTE_VAR,$(TSWO_perl_MICROPERL_MODULES)));do mkdir -p $(TSWO_RFS_INSTALL_DIR)/usr/lib/perl5/$(perl_VERSION)/`dirname $$mod`; cp -pdf lib/$$mod $(TSWO_RFS_INSTALL_DIR)/usr/lib/perl5/$(perl_VERSION)/`dirname $$mod`/;done
	@touch $@

microperl-fetch: perl-fetch
microperl-unpack: perl-unpack
microperl-patch: perl-patch
microperl-configure: microperl-patch $(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_configured
microperl-build: microperl-configure $(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_built
microperl-package: microperl-build $(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_packaged
microperl-host-install: microperl-build $(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_host_installed
microperl-rfs-install: microperl-build $(BUILD_DIR)/perl-$(perl_VERSION)/.stamp_micro_rfs_installed
microperl-clean: perl-clean
microperl-distclean: perl-distclean

# add to software list
ifeq (y,$(TSWO_SOFTWARE_perl))
ifeq (y,$(TSWO_SOFTWARE_microperl))
SOFTWARE+=microperl
else
SOFTWARE+=perl
endif
endif


# vim:set noexpandtab: 
