# Copyright (C) 2007-2010 Timesys Corporation
# busybox rules

# Define common macros for this package from include/common.mk
$(eval $(call COMMON_SETUP,busybox))

$(busybox_SRC_DL_DIR)/busybox_config:
	$(call PRINT_INFO,fetching busybox configuration)
	$(call FETCH_REMOTE,$(busybox_SRC_DL_DIR),$(TSWO_BUSYBOX_CONFIG))
	if [ ! -f $@ ]; then cp -f $(busybox_SRC_DL_DIR)/$(notdir $(call UNQUOTE_VAR,$(TSWO_BUSYBOX_CONFIG))) $@;fi

busybox-menuconfig: busybox-patch $(busybox_SRC_DL_DIR)/busybox_config
	cd $(busybox_DDIR) && \
		if [ -f $(busybox_SRC_DL_DIR)/busybox_config ]; then cp -f $(busybox_SRC_DL_DIR)/busybox_config .config;fi && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		CROSS_COMPILE=$(TSWO_FULL_TARGET_NAME)- \
		$(MAKE) KBUILD_HAVE_NLS=no menuconfig && \
		if [ -f .config ]; then cp -f .config $(busybox_SRC_DL_DIR)/busybox_config; rm -f $(busybox_DIR)/.stamp_configured;fi

$(BUILD_DIR)/busybox-$(busybox_VERSION)/busybox-$(busybox_VERSION)/.config: $(busybox_SRC_DL_DIR)/busybox_config
	cp -f $(busybox_SRC_DL_DIR)/busybox_config $(@D)/.config

$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_init_rfs_installed: DESTDIR=$(TSWO_RFS_INSTALL_DIR)
$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_init_packaged: DESTDIR=$(busybox_PKG_INSTALL_DIR)
$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_post_rfs_installed: $(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_init_rfs_installed
$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_post_packaged: $(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_init_packaged

$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_init_rfs_installed $(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_init_packaged:
	$(call PRINT_INFO,installing busybox init scripts)
	mkdir -p $(DESTDIR)/etc/{init.d,network,mdev}
	mkdir -p $(DESTDIR)/usr/share/udhcpc/
	-cp -f $(busybox_SRC_DL_DIR)/inittab $(DESTDIR)/etc/
	-cp -f $(busybox_SRC_DL_DIR)/rc{S,K} $(DESTDIR)/etc/init.d/
	-cp -f $(busybox_SRC_DL_DIR)/S[0-9][0-9]* $(DESTDIR)/etc/init.d/
	-cp -f $(busybox_SRC_DL_DIR)/mdev.conf $(DESTDIR)/etc/mdev.conf
	-cp -f $(busybox_SRC_DL_DIR)/mount.sh $(DESTDIR)/etc/mdev/mount.sh
	-cp -f $(busybox_SRC_DL_DIR)/udhcpc.script $(DESTDIR)/usr/share/udhcpc/default.script
	-cp -f $(busybox_SRC_DL_DIR)/interfaces $(DESTDIR)/etc/network/
	-chmod +x $(DESTDIR)/etc/init.d/*
	-chmod +x $(DESTDIR)/etc/mdev/mount.sh
	-chmod +x $(DESTDIR)/usr/share/udhcpc/default.script
	chmod u+s $(DESTDIR)/bin/busybox
	@touch $(@);

$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_configured:
	$(call PRINT_INFO,configuring busybox)
	$(SED) -i s,CONFIG_PREFIX=.*,CONFIG_PREFIX=\"$(TSWO_RFS_INSTALL_DIR)\",g \
		$(@D)/busybox-$(busybox_VERSION)/.config
ifneq (,$(findstring cygwin,$(TSWO_HOST_NAME)))
	$(SED) -i -r -e "s,^(HOSTCFLAGS\W:=.*)$$,\1 -DKBUILD_NO_NLS," \
		$(busybox_DDIR)/Makefile
endif
	cd $(busybox_DDIR) && \
		yes '' | \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		CROSS_COMPILE=$(TSWO_FULL_TARGET_NAME)- \
		$(MAKE) oldconfig
	@touch $(@)

busybox-fetch: $(busybox_SRC_DL_DIR)/busybox_config
busybox-patch: $(BUILD_DIR)/busybox-$(busybox_VERSION)/busybox-$(busybox_VERSION)/.config
busybox-configure: busybox-patch $(BUILD_DIR)/busybox-$(busybox_VERSION)/busybox-$(busybox_VERSION)/.config $(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_configured

$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_fix_config: $(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_pre_packaged
	$(call PRINT_INFO,prepackaging busybox)
	$(SED) -i.pkgbak s,CONFIG_PREFIX=.*,CONFIG_PREFIX=\"$(busybox_PKG_INSTALL_DIR)\",g \
		$(busybox_DDIR)/.config
	@touch $@
$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_unfix_config: $(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_packaged
	$(call PRINT_INFO,postpackaging busybox)
	if [ -e $(busybox_DDIR)/.config.pkgbak ]; then mv -f $(busybox_DDIR)/.config.pkgbak  $(busybox_DDIR)/.config;fi
	@touch $@

$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_packaged: $(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_fix_config
$(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_post_packaged: $(BUILD_DIR)/busybox-$(busybox_VERSION)/.stamp_unfix_config

# add to software list
ifeq (y,$(TSWO_SOFTWARE_busybox))
SOFTWARE+=busybox
endif

# vim:set noexpandtab: 
