# Copyright (C) 2007-2010 Timesys Corporation
# i2c-tools rules

# Typically the above are defined via the Config.in file so they can
# be set and overriden from the configuration interface. Setting them
# here is helpful when testing a new package or bypassing the configuration
# interface altogether.

# Define common macros for i2c-tools from include/common.mk
# This must come after declaring any variables.
$(eval $(call COMMON_SETUP,i2c-tools))


$(BUILD_DIR)/i2c-tools-$(i2c-tools_VERSION)/.stamp_configured:
	@touch $@

$(BUILD_DIR)/i2c-tools-$(i2c-tools_VERSION)/.stamp_built:
	$(call PRINT_INFO,building i2c-tools $(i2c-tools_VERSION))
	cd $(i2c-tools_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(i2c-tools_MAKE_CMD) \
			$(TARGET_ALIASES) \
			$(TARGET_BUILD_OPTIONS) \
      $(i2c-tools_BUILD_OPTIONS)
	@touch $@

$(BUILD_DIR)/i2c-tools-$(i2c-tools_VERSION)/.stamp_rfs_installed:
	$(call PRINT_INFO,installing i2c-tools $(i2c-tools_VERSION) to the RFS)
	@mkdir -p $(TSWO_RFS_INSTALL_DIR)
	cd $(i2c-tools_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) $(i2c-tools_MAKE_CMD) DESTDIR=$(TSWO_RFS_INSTALL_DIR) install \
			prefix=/usr $(TARGET_ALIASES) \
      $(i2c-tools_BUILD_OPTIONS)
	@touch $@

$(BUILD_DIR)/i2c-tools-$(i2c-tools_VERSION)/.stamp_host_installed:
	$(call PRINT_INFO,installing i2c-tools $(i2c-tools_VERSION) to host)
	@mkdir -p $(TSWO_HOST_INSTALL_DIR)
	cd $(i2c-tools_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(FAKEROOT_CMD) $(i2c-tools_MAKE_CMD) DESTDIR=$(TSWO_HOST_INSTALL_DIR) install \
			prefix=/usr $(TARGET_ALIASES) \
      $(i2c-tools_BUILD_OPTIONS)
	$(call FIX_LIBTOOL_ARCHIVES,$(TSWO_HOST_INSTALL_DIR))
	$(call FIX_CONFIG_SCRIPTS,$(TSWO_HOST_INSTALL_DIR))
	rm -f $(TSWO_HOST_INSTALL_DIR)/usr/bin/{ddcmon,decode-dimms,decode-edid,decode-vaio}
	rm -f $(TSWO_HOST_INSTALL_DIR)/usr/sbin/{i2cdetect,i2cdump,i2cget,i2cset,i2c-stub-from-dump}
	@touch $@

$(BUILD_DIR)/i2c-tools-$(i2c-tools_VERSION)/.stamp_packaged:
	cd $(i2c-tools_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
		$(FAKEROOT_CMD) $(i2c-tools_MAKE_CMD) DESTDIR=$(i2c-tools_PKG_INSTALL_DIR) install \
        prefix=/usr $(i2c-tools_BUILD_OPTIONS)
	@touch $@


# add to software list of packages to be built, packaged,
# and installed to the rfs (depending on the configuration)
ifeq (y,$(TSWO_SOFTWARE_i2c-tools))
SOFTWARE+=i2c-tools
endif


# vim:set noexpandtab filetype=make: 
