# Copyright (C) 2007-2010 Timesys Corporation
# udev rules

# Define common macros for this udev from include/common.mk
$(eval $(call COMMON_SETUP,udev))

ifeq (y,$(TSWO_udev_BUILD_EXTRAS))
udev-patch: host-gperf-host-install acl-host-install glib2-host-install pciutils-host-install usbutils-host-install
udev_CONFIGURE_OPTIONS+=ac_cv_file__usr_share_pci_ids=no ac_cv_file__usr_share_hwdata_pci_ids=no ac_cv_file__usr_share_misc_pci_ids=no --with-pci-ids-path=/usr/share/pci.ids.gz
udev_BUILD_OPTIONS+=USB_DATABASE=/usr/share/usb.ids.gz
else
udev_CONFIGURE_OPTIONS+=--disable-extras
endif

# if libvolume_id is selected, make sure it is installed first
ifeq (y,$(TSWO_SOFTWARE_libvolume_id))
udev-patch: libvolume_id-host-install
udev-rfs-install: libvolume_id-rfs-install
endif

# 117 and 118 do not have configure steps
ifeq (117,$(strip $(call UNQUOTE_VAR,$(TSWO_udev_VERSION))))
$(BUILD_DIR)/udev-$(udev_VERSION)/.stamp_configured:
	@touch $@
endif
ifeq (118,$(strip $(call UNQUOTE_VAR,$(TSWO_udev_VERSION))))
$(BUILD_DIR)/udev-$(udev_VERSION)/.stamp_configured:
	@touch $@
endif

# XXX make all default device entries with group root (revisit later)
$(BUILD_DIR)/udev-$(udev_VERSION)/.stamp_post_configured:
	@cd $(udev_DDIR) && \
		find . -name '[0-9]*.rules' -exec sed -i -re "s/GROUP=\"[a-zA-Z0-9]+\"/GROUP=\"root\"/" {} \;
	@touch $@

$(BUILD_DIR)/udev-$(udev_VERSION)/.stamp_packaged:
	cd $(udev_DDIR) && \
		PATH=$(BUILD_PATH) \
		$(TARGET_ALIASES) \
        $(udev_BUILD_OPTIONS) \
		$(FAKEROOT_CMD) $(udev_MAKE_CMD) DESTDIR=$(udev_PKG_INSTALL_DIR) install
	mkdir -p $(udev_PKG_INSTALL_DIR)/etc/init.d
	-cp -f $(udev_SRC_DL_DIR)/S01-udev $(udev_PKG_INSTALL_DIR)/etc/init.d/
	-chmod +x $(udev_PKG_INSTALL_DIR)/etc/init.d/S01-udev
	@touch $@

$(BUILD_DIR)/udev-$(udev_VERSION)/.stamp_post_rfs_installed:
	$(call PRINT_INFO,performing post install steps for udev)
	mkdir -p $(TSWO_RFS_INSTALL_DIR)/etc/init.d
	-cp -f $(udev_SRC_DL_DIR)/S01-udev $(TSWO_RFS_INSTALL_DIR)/etc/init.d/
	-chmod +x $(TSWO_RFS_INSTALL_DIR)/etc/init.d/S01-udev
	@touch $@

$(BUILD_DIR)/udev-$(udev_VERSION)/.stamp_post_host_installed:
	rm -f $(TSWO_HOST_INSTALL_DIR)/lib/libvolume_id.so
	cd $(TSWO_HOST_INSTALL_DIR)/lib/ && \
		ln -sf libvolume_id.so.1.* libvolume_id.so
	rm -f $(TSWO_HOST_INSTALL_DIR)/lib/libudev.so
	cd $(TSWO_HOST_INSTALL_DIR)/lib/ && \
		ln -sf libudev.so.0.* libudev.so
	@touch $@

# add to software list
ifeq (y,$(TSWO_SOFTWARE_udev))
SOFTWARE+=udev
endif


# vim:set noexpandtab: 
